@@ -34,7 +34,7 @@
 #include <io-context.h>
 #include <command-context.h>
 #include <command-context-stderr.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 
 #include <bonobo.h>
 
@@ -55,7 +55,7 @@ capp_workbook_open (PortableServer_Servant ignore,
 		    CORBA_boolean          shared_view,
 		    CORBA_Environment     *ev)
 {
-	Workbook     *wb = application_workbook_get_by_name (file_name);
+	Workbook     *wb = gnm_app_workbook_get_by_name (file_name);
 	WorkbookView *wbv;
 
 	if (wb != NULL) {
@@ -64,8 +64,8 @@ capp_workbook_open (PortableServer_Servant ignore,
 		else
 			wbv = NULL;
 	} else {
-		CommandContextStderr *cc = command_context_stderr_new ();
-		IOContext *io_context = gnumeric_io_context_new (COMMAND_CONTEXT (cc));
+		GnmCmdContext *cc = cmd_context_stderr_new ();
+		IOContext *io_context = gnumeric_io_context_new (cc);
 		wbv = wb_view_new_from_file (file_name, NULL, io_context, NULL);
 		g_object_unref (G_OBJECT (io_context));
 		g_object_unref (G_OBJECT (cc));
@@ -78,7 +78,7 @@ static GNOME_Gnumeric_Workbooks *
 capp_workbooks (PortableServer_Servant ignore,
 		CORBA_Environment     *ev)
 {
-	GList *workbooks = application_workbook_list ();
+	GList *workbooks = gnm_app_workbook_list ();
 	int i, len = g_list_length (workbooks);
 	GNOME_Gnumeric_Workbooks *res = GNOME_Gnumeric_Workbooks__alloc ();
 	res->_length = res->_maximum = len;
@@ -103,7 +103,7 @@ capp_class_init (CorbaApplicationClass *capp)
 	capp->epv.workbook_open	= capp_workbook_open;
 }
 
-BONOBO_TYPE_FUNC_FULL (CorbaApplication, 
+static BONOBO_TYPE_FUNC_FULL (CorbaApplication, 
 		       GNOME_Gnumeric_Application,
 		       BONOBO_OBJECT_TYPE,
 		       capp);
@@ -125,9 +125,9 @@ plugin_init_general (ErrorInfo **ret_error)
 
 	capp = g_object_new (capp_get_type(), NULL);
 
-	bonobo_activation_active_server_register (
+	bonobo_activation_register_active_server (
 		"OAFIID:GNOME_Gnumeric_Application",
-		BONOBO_OBJREF (capp));
+		BONOBO_OBJREF (capp), NULL);
 	/* FIXME: this badly needs to check return values */
 }
 
@@ -135,7 +135,7 @@ void
 plugin_cleanup_general (ErrorInfo **ret_error)
 {
 	if (capp) {
-		bonobo_activation_active_server_unregister (
+		bonobo_activation_unregister_active_server (
 			"OAFIID:GNOME_Gnumeric_Application",
 			BONOBO_OBJREF (capp));
 		bonobo_object_unref (capp);
