@@ -13,6 +13,11 @@
 #include "rc4.h"
 #include "md5.h"
 
+typedef enum { MS_BIFF_CRYPTO_NONE = 0,
+	       MS_BIFF_CRYPTO_XOR,
+	       MS_BIFF_CRYPTO_RC4,
+	       MS_BIFF_CRYPTO_UNKNOWN } MsBiffCrypto ;
+
 typedef enum { MS_BIFF_V2 = 2,
 	       MS_BIFF_V3 = 3,
 	       MS_BIFF_V4 = 4,
@@ -41,7 +46,8 @@ typedef struct {
 	guint32 streamPos;
 	GsfInput *input;
 
-	gboolean is_encrypted;
+	MsBiffCrypto encryption;
+	guint8   xor_key[16];
 	RC4_KEY	 rc4_key;
 	MD5_CTX  md5_ctxt;
 	int	 block;
@@ -54,10 +60,12 @@ gboolean    ms_biff_query_set_decrypt (BiffQuery *q, MsBiffVersion version,
 				       char const *password);
 
 /* Updates the BiffQuery structure with the next BIFF record
- * returns: 1 for succes, and 0 for EOS(tream) */
-int         ms_biff_query_next        (BiffQuery *);
+ * returns: TRUE for succes, and FALSE for EOS(tream) */
+gboolean    ms_biff_query_next        (BiffQuery *);
 gboolean    ms_biff_query_peek_next   (BiffQuery *, guint16 *opcode);
 void        ms_biff_query_destroy     (BiffQuery *);
+void        ms_biff_query_dump	      (BiffQuery *);
+
 
 /*******************************************************************************/
 /*                                 Write Side                                  */
@@ -102,6 +110,5 @@ void     ms_biff_put_var_seekto (BiffPut *bp, int pos);
 void     ms_biff_put_commit     (BiffPut *bp);
 
 unsigned ms_biff_max_record_len (BiffPut const *bp);
-void dump_biff (BiffQuery *bq);
 
 #endif /* GNUMERIC_BIFF_H */
