@@ -9,7 +9,7 @@
  * (C) 1998-2003 Michael Meeks, Jody Goldberg
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "ms-formula-read.h"
 #include "excel.h"
@@ -1510,7 +1510,7 @@ excel_parse_formula (MSContainer const *container,
 					a = container->ewb->container.names;
 					sheet_idx = -sheet_idx;
 				} else
-					a = container->v7.externnames;
+					a = container->names;
 				sheet = excel_externsheet_v7 (container, sheet_idx);
 				ptg_length = 24;
 			}
