@@ -22,7 +22,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include <func.h>
 
@@ -979,7 +979,7 @@ typedef struct
 
 static GnmValue *
 networkdays_holiday_callback (GnmValue const *v, GnmEvalPos const *ep,
-			      int x, int y, void *user_data)
+			      void *user_data)
 {
 	networkdays_holiday_closure * close =
 	    (networkdays_holiday_closure *)user_data;
