@@ -30,7 +30,7 @@
  * copyright on the CELL implementation.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include <func.h>
 
@@ -121,8 +121,8 @@ static const translate_t translate_table[] = {
 	{ "h:mm:ss", "D8" }
 };
 
-static Value *
-translate_cell_format (StyleFormat const *format)
+static GnmValue *
+translate_cell_format (GnmFormat const *format)
 {
 	int i;
 	char *fmt;
@@ -153,21 +153,21 @@ translate_cell_format (StyleFormat const *format)
 static FormatCharacteristics
 retrieve_format_info (Sheet *sheet, int col, int row)
 {
-	MStyle *mstyle = sheet_style_get (sheet, col, row);
-	StyleFormat *format = mstyle_get_format (mstyle);
+	GnmStyle *mstyle = sheet_style_get (sheet, col, row);
+	GnmFormat *format = mstyle_get_format (mstyle);
 	return format->family_info;
 }
 
 /* TODO : turn this into a range based routine */
-static Value *
-gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_cell (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *info_type = value_peek_string (argv[0]);
-	CellRef const *ref = &argv [1]->v_range.cell.a;
+	GnmCellRef const *ref = &argv [1]->v_range.cell.a;
 
 	/* from CELL - limited usefulness! */
 	if (!g_ascii_strcasecmp(info_type, "address")) {
-		ParsePos pp;
+		GnmParsePos pp;
 		GString *str = g_string_new (NULL);
 
 		cellref_as_string (
@@ -180,8 +180,8 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 
 	/* from later 123 versions - USEFUL! */
 	} else if (!g_ascii_strcasecmp(info_type, "coord")) {
-		ParsePos pp;
-		CellRef tmp = *ref;
+		GnmParsePos pp;
+		GnmCellRef tmp = *ref;
 		GString *str = g_string_new (NULL);
 
 		if (tmp.sheet == NULL)
@@ -222,10 +222,10 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 	/* absolutely pointless - compatibility only */
 	} else if (!g_ascii_strcasecmp (info_type, "contents") ||
 		   !g_ascii_strcasecmp (info_type, "value")) {
-		Cell const *cell =
+		GnmCell const *cell =
 			sheet_cell_get (ei->pos->sheet, ref->col, ref->row);
 		if (cell && cell->value)
-			return value_duplicate (cell->value);
+			return value_dup (cell->value);
 		return value_new_empty ();
 
 	/* from CELL - limited usefulness!
@@ -244,7 +244,7 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 	/* from CELL */
 	/* Backwards compatibility w/123 - unnecessary */
 	} else if (!g_ascii_strcasecmp (info_type, "format")) {
-		MStyle const *mstyle =
+		GnmStyle const *mstyle =
 			sheet_style_get (ei->pos->sheet, ref->col, ref->row);
 
 		return translate_cell_format (mstyle_get_format (mstyle));
@@ -263,9 +263,9 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 	/* Backwards compatibility w/123 - unnecessary */
 	} else if (!g_ascii_strcasecmp (info_type, "prefix") ||
 		   !g_ascii_strcasecmp (info_type, "prefixcharacter")) {
-		MStyle const *mstyle =
+		GnmStyle const *mstyle =
 			sheet_style_get (ei->pos->sheet, ref->col, ref->row);
-		Cell const *cell =
+		GnmCell const *cell =
 			sheet_cell_get (ei->pos->sheet, ref->col, ref->row);
 
 		if (cell && cell->value && cell->value->type == VALUE_STRING) {
@@ -283,7 +283,7 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 	/* from CELL */
 	} else if (!g_ascii_strcasecmp (info_type, "locked") ||
 		   !g_ascii_strcasecmp (info_type, "protect")) {
-		MStyle const *mstyle =
+		GnmStyle const *mstyle =
 			sheet_style_get (ei->pos->sheet, ref->col, ref->row);
 		return value_new_int (mstyle_get_content_locked (mstyle) ? 1 : 0);
 
@@ -314,7 +314,7 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 	} else if (!g_ascii_strcasecmp (info_type, "type") ||
 		   !g_ascii_strcasecmp (info_type, "datatype") ||
 		   !g_ascii_strcasecmp (info_type, "formulatype")) {
-		Cell const *cell =
+		GnmCell const *cell =
 			sheet_cell_get (ei->pos->sheet, ref->col, ref->row);
 		if (cell && cell->value) {
 			if (cell->value->type == VALUE_STRING)
@@ -1166,14 +1166,14 @@ static char const *help_expression = {
 	   "@SEEALSO=TEXT")
 };
 
-static Value *
-gnumeric_expression (FunctionEvalInfo *ei, Value **args)
+static GnmValue *
+gnumeric_expression (FunctionEvalInfo *ei, GnmValue **args)
 {
-	Value const * const v = args[0];
+	GnmValue const * const v = args[0];
 	if (v->type == VALUE_CELLRANGE) {
-		Cell *cell;
-		CellRef const * a = &v->v_range.cell.a;
-		CellRef const * b = &v->v_range.cell.b;
+		GnmCell *cell;
+		GnmCellRef const * a = &v->v_range.cell.a;
+		GnmCellRef const * b = &v->v_range.cell.b;
 
 		if (a->col != b->col || a->row != b->row || a->sheet !=b->sheet)
 			return value_new_error_REF (ei->pos);
@@ -1182,7 +1182,7 @@ gnumeric_expression (FunctionEvalInfo *ei, Value **args)
 				       a->col, a->row);
 
 		if (cell && cell_has_expr (cell)) {
-			ParsePos pos;
+			GnmParsePos pos;
 			char *expr_string = gnm_expr_as_string (cell->base.expression,
 				parse_pos_init_cell (&pos, cell),
 				gnm_expr_conventions_default);
@@ -1210,9 +1210,9 @@ static char const *help_countblank = {
            "@SEEALSO=COUNT")
 };
 
-static Value *
+static GnmValue *
 cb_countblank (Sheet *sheet, int col, int row,
-	       Cell *cell, void *user_data)
+	       GnmCell *cell, void *user_data)
 {
 	cell_eval (cell);
 	if (!cell_is_empty (cell))
@@ -1220,11 +1220,11 @@ cb_countblank (Sheet *sheet, int col, int row,
 	return NULL;
 }
 
-static Value *
-gnumeric_countblank (FunctionEvalInfo *ei, Value **args)
+static GnmValue *
+gnumeric_countblank (FunctionEvalInfo *ei, GnmValue **args)
 {
 	Sheet *start_sheet, *end_sheet;
-	Range r;
+	GnmRange r;
 	int count;
 
 	rangeref_normalize (&args[0]->v_range.cell, ei->pos,
@@ -1267,8 +1267,8 @@ static char const *help_info = {
 };
 
 
-static Value *
-gnumeric_info (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_info (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const * const info_type = value_peek_string (argv[0]);
 	if (!g_ascii_strcasecmp (info_type, "directory")) {
@@ -1343,8 +1343,8 @@ static char const *help_iserror = {
 	   "@SEEALSO=ERROR")
 };
 
-static Value *
-gnumeric_iserror (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_iserror (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (argv[0]->type == VALUE_ERROR);
 }
@@ -1369,8 +1369,8 @@ static char const *help_isna = {
  * We need to operator directly in the input expression in order to bypass
  * the error handling mechanism
  */
-static Value *
-gnumeric_isna (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_isna (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (value_error_classify (argv[0]) == GNM_ERROR_NA);
 }
@@ -1391,8 +1391,8 @@ static char const *help_iserr = {
 	   "@SEEALSO=ISERROR")
 };
 
-static Value *
-gnumeric_iserr (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_iserr (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (argv[0]->type == VALUE_ERROR &&
 			       value_error_classify (argv[0]) != GNM_ERROR_NA);
@@ -1421,8 +1421,8 @@ static char const *help_error_type = {
 	   "@SEEALSO=ISERROR")
 };
 
-static Value *
-gnumeric_error_type (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_error_type (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	switch (value_error_classify (argv[0])) {
 	case GNM_ERROR_NULL: return value_new_int (1);
@@ -1453,8 +1453,8 @@ static char const *help_na = {
 	   "@SEEALSO=ISNA")
 };
 
-static Value *
-gnumeric_na (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_na (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_error_NA (ei->pos);
 }
@@ -1474,8 +1474,8 @@ static char const *help_error = {
 	   "@SEEALSO=ISERROR")
 };
 
-static Value *
-gnumeric_error (FunctionEvalInfo *ei, Value *argv[])
+static GnmValue *
+gnumeric_error (FunctionEvalInfo *ei, GnmValue *argv[])
 {
 	return value_new_error (ei->pos, value_peek_string (argv[0]));
 }
@@ -1496,38 +1496,10 @@ static char const *help_isblank = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_isblank (FunctionEvalInfo *ei, GnmExprList *expr_node_list)
+static GnmValue *
+gnumeric_isblank (FunctionEvalInfo *ei, GnmValue **argv)
 {
-	gboolean result = FALSE;
-	GnmExpr const *expr;
-	if (gnm_expr_list_length (expr_node_list) != 1)
-		return value_new_error (ei->pos,
-					_("Invalid number of arguments"));
-
-	expr = expr_node_list->data;
-
-	/* How can this happen ? */
-	if (expr == NULL)
-		return value_new_bool (FALSE);
-
-	/* Handle pointless arrays */
-	if (expr->any.oper == GNM_EXPR_OP_ARRAY) {
-		if (expr->array.rows != 1 || expr->array.cols != 1)
-			return value_new_bool (FALSE);
-		expr = expr->array.corner.expr;
-	}
-
-	if (expr->any.oper == GNM_EXPR_OP_CELLREF) {
-		CellRef const *ref = &expr->cellref.ref;
-		Sheet const *sheet = eval_sheet (ref->sheet, ei->pos->sheet);
-		CellPos pos;
-
-		cellref_get_abs_pos (ref, &ei->pos->eval, &pos);
-		result = cell_is_empty (sheet_cell_get (sheet, pos.col,
-							pos.row));
-	}
-	return value_new_bool (result);
+	return value_new_bool (argv[0]->type == VALUE_EMPTY);
 }
 
 /***************************************************************************/
@@ -1546,8 +1518,8 @@ static char const *help_iseven = {
 	   "@SEEALSO=ISODD")
 };
 
-static Value *
-gnumeric_iseven (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_iseven (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (!(value_get_as_int (argv[0]) & 1));
 }
@@ -1568,8 +1540,8 @@ static char const *help_islogical = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_islogical (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_islogical (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (argv[0]->type == VALUE_BOOLEAN);
 }
@@ -1590,8 +1562,8 @@ static char const *help_isnontext = {
 	   "@SEEALSO=ISTEXT")
 };
 
-static Value *
-gnumeric_isnontext (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_isnontext (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (argv[0]->type != VALUE_STRING);
 }
@@ -1612,11 +1584,11 @@ static char const *help_isnumber = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_isnumber (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_isnumber (FunctionEvalInfo *ei, GnmValue **argv)
 {
-	return value_new_bool (argv[0]->type == VALUE_INTEGER ||
-			       argv[0]->type == VALUE_FLOAT);
+	return value_new_bool (argv[0] != NULL &&
+		(argv[0]->type == VALUE_INTEGER || argv[0]->type == VALUE_FLOAT));
 }
 
 /***************************************************************************/
@@ -1635,8 +1607,8 @@ static char const *help_isodd = {
 	   "@SEEALSO=ISEVEN")
 };
 
-static Value *
-gnumeric_isodd (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_isodd (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (value_get_as_int (argv[0]) & 1);
 }
@@ -1657,7 +1629,7 @@ static char const *help_isref = {
 	   "@SEEALSO=")
 };
 
-static Value *
+static GnmValue *
 gnumeric_isref (FunctionEvalInfo *ei, GnmExprList *expr_node_list)
 {
 	GnmExpr *t;
@@ -1689,8 +1661,8 @@ static char const *help_istext = {
 	   "@SEEALSO=ISNONTEXT")
 };
 
-static Value *
-gnumeric_istext (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_istext (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (argv[0]->type == VALUE_STRING);
 }
@@ -1712,17 +1684,17 @@ static char const *help_n = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_n (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_n (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *str;
-	Value *v;
+	GnmValue *v;
 
 	if (argv[0]->type == VALUE_BOOLEAN)
 		return value_new_int (value_get_as_int(argv[0]));
 
 	if (VALUE_IS_NUMBER (argv[0]))
-		return value_duplicate (argv[0]);
+		return value_dup (argv[0]);
 
 	if (argv[0]->type != VALUE_STRING)
 		return value_new_error_NUM (ei->pos);
@@ -1757,8 +1729,8 @@ static char const *help_type = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_type (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_type (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	switch (argv[0]->type) {
 	/* case VALUE_EMPTY : not possible, S arguments convert this to int(0)
@@ -1800,8 +1772,8 @@ static char const *help_getenv = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_getenv (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_getenv (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *var = value_peek_string (argv[0]);
 	char const *val = getenv (var);
@@ -1824,8 +1796,8 @@ const GnmFuncDescriptor info_functions[] = {
 	{ "info",	"s", N_("info_type"), &help_info,
 	  gnumeric_info, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-	{ "isblank",	NULL, N_("value"), &help_isblank,
-	  NULL, gnumeric_isblank, NULL, NULL, NULL,
+	{ "isblank",	"E", N_("value"), &help_isblank,
+	  gnumeric_isblank, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "iserr",	"E",   N_("value"), &help_iserr,
 	  gnumeric_iserr, NULL, NULL, NULL, NULL,
@@ -1845,7 +1817,7 @@ const GnmFuncDescriptor info_functions[] = {
 	{ "isnontext",	"E", N_("value"), &help_isnontext,
 	  gnumeric_isnontext, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-	{ "isnumber",	"E", N_("value"), &help_isnumber,
+	{ "isnumber",	"B", N_("value"), &help_isnumber,
 	  gnumeric_isnumber, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "isodd",	"S", N_("value"), &help_isodd,
