@@ -22,7 +22,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include <func.h>
 
@@ -756,7 +756,10 @@ gnumeric_ceiling (FunctionEvalInfo *ei, GnmValue **argv)
 	        s = value_get_as_float (argv[1]);
 	}
 
-	if (s == 0 || number / s < 0)
+	if (s == 0)
+		return value_new_error_DIV0 (ei->pos);
+
+	if (number / s < 0)
 		return value_new_error_NUM (ei->pos);
 
 	return value_new_float (gnumeric_fake_ceil (number / s) * s);
@@ -920,7 +923,7 @@ gnumeric_beta (FunctionEvalInfo *ei, GnmValue **argv)
 	gnm_float a = value_get_as_float (argv[0]);
 	gnm_float b = value_get_as_float (argv[1]);
 
-#warning improve error handling.  Relying on value_new_float to do it is cheesy
+#warning "Improve error handling.  Relying on value_new_float to do it is cheesy"
 	return value_new_float (beta (a, b));
 }
 
@@ -1018,7 +1021,10 @@ gnumeric_floor (FunctionEvalInfo *ei, GnmValue **argv)
 	else
 	        s = value_get_as_float (argv[1]);
 
-	if (s == 0 || (number / s) < 0)
+	if (s == 0)
+		return value_new_error_DIV0 (ei->pos);
+
+	if (number / s < 0)
 		return value_new_error_NUM (ei->pos);
 
 	return value_new_float (gnumeric_fake_floor (number / s) * s);
