@@ -23,7 +23,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include <func.h>
 
@@ -249,19 +249,18 @@ gnumeric_len (FunctionEvalInfo *ei, GnmValue **argv)
 
 /***************************************************************************/
 static char const *help_lenb = {
-	"@FUNCTION=LENB\n"
+	N_("@FUNCTION=LENB\n"
 	   "@SYNTAX=LENB(string)\n"
 
 	   "@DESCRIPTION="
-	   "LEN returns the length in bytes of the string @string.\n\n"
+	   "LENB returns the length in bytes of the string @string.\n\n"
            "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
-	   "LEN(\"Helsinki\") equals 8.\n"
+	   "LENB(\"Helsinki\") equals 8.\n"
 	   "\n"
-	   "@SEEALSO=CHAR, CODE, LEN"
+	   "@SEEALSO=CHAR, CODE, LEN")
 };
-#warning MARK for translation
 
 static GnmValue *
 gnumeric_lenb (FunctionEvalInfo *ei, GnmValue **argv)
@@ -651,14 +650,14 @@ gnumeric_fixed (FunctionEvalInfo *ei, GnmValue **argv)
 	fmt.left_spaces		   = 0;
 	fmt.left_req		   = 0;
 	fmt.decimal_separator_seen = (decimals > 0);
-	fmt.supress_minus	   = FALSE;
 	fmt.group_thousands	   = commas;
 	fmt.has_fraction	   = FALSE;
-	fmt.negative		   = num < 0.;
-	if (fmt.negative)
-		num = -num;
 
 	str = g_string_new (NULL);
+	if (num < 0.) {
+		num = -num;
+		g_string_append_c (str, '-');
+	}
 	render_number (str, num, &fmt);
 	if (str->len == 0)
 		g_string_append_c (str, '0');
@@ -813,37 +812,28 @@ static char const *help_text = {
 static GnmValue *
 gnumeric_text (FunctionEvalInfo *ei, GnmValue **args)
 {
-	GnmFormat *format = style_format_new_XL (value_peek_string (args[1]),
-						   TRUE);
-	GnmValue       *res, *tmp = NULL;
-	GnmValue const *arg  = args[0];
-	gboolean    ok = FALSE;
+	GnmValue       *res, *match = NULL;
+	GnmValue const *v  = args[0];
+	GnmFormat *fmt;
 	GnmDateConventions const *conv =
 		workbook_date_conv (ei->pos->sheet->workbook);
 
-	if (arg->type == VALUE_STRING) {
-		GnmValue *match = format_match (value_peek_string (arg), NULL, conv);
-		ok = (match != NULL);
-		if (ok)
-			tmp = match;
-	} else
-		ok = VALUE_IS_NUMBER (arg);
+	if (v->type == VALUE_STRING) {
+		match = format_match (value_peek_string (v), NULL, conv);
+		if (match != NULL)
+			v = match;
+	}
+	fmt = style_format_new_XL (value_peek_string (args[1]), TRUE);
+	res = value_new_string_nocopy (
+		format_value (fmt, v, NULL, -1, conv));
+	style_format_unref (fmt);
 
-	if (ok) {
-		char *str = format_value (format,
-					  (tmp != NULL) ? tmp : arg,
-					  NULL, -1, conv);
-		res = value_new_string_nocopy (str);
-	} else
-		res = value_new_error (ei->pos, _("Type mismatch"));
+	if (match != NULL)
+		value_release (match);
 
-	if (tmp != NULL)
-		value_release (tmp);
-	style_format_unref (format);
 	return res;
 }
 
-
 /***************************************************************************/
 
 static char const *help_trim = {
