@@ -1,6 +1,6 @@
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <glib.h>
 
 #include <workbook-control-gui.h>
