@@ -6,7 +6,7 @@
  *    Michael Meeks <mmeeks@gnu.org>
  **/
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "lotus.h"
 #include "lotus-types.h"
