@@ -21,7 +21,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 
 #include "func.h"
@@ -60,7 +60,7 @@ typedef struct {
 
 typedef struct {
 	GnmExprFunction const *node;  /* Expression node that calls us */
-	Dependent *dep;		   /* Dependent containing that node */
+	GnmDependent *dep;	      /* GnmDependent containing that node */
 
 	WatchedValue	*value;
 } Watcher;
@@ -204,8 +204,8 @@ plugin_cleanup (void)
 	watchers = NULL;
 }
 
-static Value *
-atl_last (FunctionEvalInfo *ei, Value *argv[])
+static GnmValue *
+atl_last (FunctionEvalInfo *ei, GnmValue *argv[])
 {
 	WatchedValue *val = watched_value_fetch (value_peek_string (argv[0]));
 
