@@ -21,7 +21,6 @@
 #include "auto-correct.h"
 #include "gutils.h"
 #include "pixmaps/gnumeric-stock-pixbufs.h"
-#include "gnm-marshalers.h"
 
 #include <gnumeric-gconf.h>
 #include <gsf/gsf-impl-utils.h>
@@ -60,7 +59,6 @@ struct _GnmApp {
 	GSList           *history_list;
 
 	/* Others */
-	GConfClient     *gconf_client;
 	GtkWidget       *pref_dialog;
 
 	GList		*workbook_list;
@@ -488,31 +486,6 @@ void     gnm_app_set_transition_keys  (gboolean state)
 	((GnmAppPrefs *)gnm_app_prefs)->transition_keys = state;
 }
 
-GConfClient *
-gnm_app_get_gconf_client (void)
-{
-	g_return_val_if_fail (app != NULL, NULL);
-	if (!app->gconf_client) {
-		app->gconf_client = gconf_client_get_default ();
-		gconf_client_add_dir (app->gconf_client, "/apps/gnumeric",
-				      GCONF_CLIENT_PRELOAD_RECURSIVE,
-				      NULL);
-	}
-	return app->gconf_client;
-}
-
-void
-gnm_app_release_gconf_client (void)
-{
-	g_return_if_fail (app != NULL);
-	if (app->gconf_client) {
-		gconf_client_remove_dir (app->gconf_client,
-					 "/apps/gnumeric", NULL);
-		g_object_unref (G_OBJECT (app->gconf_client));
-	}
-	app->gconf_client = NULL;
-}
-
 /*
  * Get a named pixbuf.
  */
@@ -703,6 +676,9 @@ gnumeric_application_setup_icons (void)
 		{ gnm_link_internal_24,			gnm_link_internal_16,		"Gnumeric_Link_Internal" },
 		{ gnm_link_email_24,			gnm_link_email_16,		"Gnumeric_Link_EMail" },
 		{ gnm_link_url_24,			gnm_link_url_16,		"Gnumeric_Link_URL" },
+
+		{ gnm_autofilter_24,			gnm_autofilter_16,		"Gnumeric_AutoFilter" },
+		{ gnm_autofilter_delete_24,		gnm_autofilter_delete_16,	"Gnumeric_AutoFilterDelete" }
 	};
 	static gboolean done = FALSE;
 
@@ -763,7 +739,7 @@ gnm_app_class_init (GObjectClass *gobject_klass)
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (GnmAppClass, workbook_added),
 		(GSignalAccumulator) NULL, NULL,
-		gnm__VOID__OBJECT,
+		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE,
 		1, WORKBOOK_TYPE);
 	signals [WORKBOOK_REMOVED] = g_signal_new ("workbook_removed",
@@ -771,7 +747,7 @@ gnm_app_class_init (GObjectClass *gobject_klass)
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (GnmAppClass, workbook_removed),
 		(GSignalAccumulator) NULL, NULL,
-		gnm__VOID__POINTER,
+		g_cclosure_marshal_VOID__POINTER,
 		G_TYPE_NONE,
 		1, G_TYPE_POINTER);
 	signals [CLIPBOARD_MODIFIED] = g_signal_new ("clipboard_modified",
@@ -779,7 +755,7 @@ gnm_app_class_init (GObjectClass *gobject_klass)
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (GnmAppClass, clipboard_modified),
 		(GSignalAccumulator) NULL, NULL,
-		gnm__VOID__VOID,
+		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE,
 		0);
 }
@@ -792,8 +768,6 @@ gnm_app_init (GObject *obj)
 	gnm_app->clipboard_copied_contents = NULL;
 	gnm_app->clipboard_sheet_view = NULL;
 
-	gnm_app->gconf_client = NULL;
-
 	gnm_app->workbook_list = NULL;
 
 	gnm_app->named_pixbufs = g_hash_table_new_full (g_str_hash, g_str_equal,
