@@ -2,7 +2,6 @@
 #define GNUMERIC_APPLICATION_H
 
 #include "gnumeric.h"
-#include <gconf/gconf-client.h>
 #include <glib-object.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
@@ -32,8 +31,6 @@ gboolean     gnm_app_live_scrolling	  (void);
 int	     gnm_app_auto_expr_recalc_lag (void);
 
 /* stuff that should move */
-void         gnm_app_release_gconf_client (void);
-GConfClient *gnm_app_get_gconf_client	  (void);
 GdkPixbuf   *gnm_app_get_pixbuf		  (char const *name);
 void         gnm_app_release_pref_dialog  (void);
 gpointer     gnm_app_get_pref_dialog	  (void);
