@@ -20,7 +20,7 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "cmd-edit.h"
 
@@ -43,17 +43,17 @@
 #include <gtk/gtk.h>
 
 /**
- * cmd_select_cur_row:
+ * sv_select_cur_row:
  * @sv: The sheet
  *
  * Selects an entire row
  */
 void
-cmd_select_cur_row (SheetView *sv)
+sv_select_cur_row (SheetView *sv)
 {
-	Range const *sel = selection_first_range (sv,  NULL, NULL);
+	GnmRange const *sel = selection_first_range (sv,  NULL, NULL);
 	if (sel != NULL) {
-		Range r = *sel;
+		GnmRange r = *sel;
 		sv_selection_reset (sv);
 		sv_selection_add_range (sv,
 			sv->edit_pos.col, sv->edit_pos.row,
@@ -63,17 +63,17 @@ cmd_select_cur_row (SheetView *sv)
 }
 
 /**
- * cmd_select_cur_col:
+ * sv_select_cur_col:
  * @sv: The sheet
  *
  * Selects an entire column
  */
 void
-cmd_select_cur_col (SheetView *sv)
+sv_select_cur_col (SheetView *sv)
 {
-	Range const *sel = selection_first_range (sv,  NULL, NULL);
+	GnmRange const *sel = selection_first_range (sv,  NULL, NULL);
 	if (sel != NULL) {
-		Range r = *sel;
+		GnmRange r = *sel;
 		sv_selection_reset (sv);
 		sv_selection_add_range (sv,
 			sv->edit_pos.col, sv->edit_pos.row,
@@ -83,14 +83,14 @@ cmd_select_cur_col (SheetView *sv)
 }
 
 /**
- * cmd_select_cur_array :
+ * sv_select_cur_array :
  * @sv: The sheet
  *
  * if the current cell is part of an array select
  * the entire array.
  */
 void
-cmd_select_cur_array (SheetView *sv)
+sv_select_cur_array (SheetView *sv)
 {
 	GnmExprArray const *array;
 	int col, row;
@@ -118,8 +118,8 @@ cmd_select_cur_array (SheetView *sv)
 static gint
 cb_compare_deps (gconstpointer a, gconstpointer b)
 {
-	Cell const *cell_a = a;
-	Cell const *cell_b = b;
+	GnmCell const *cell_a = a;
+	GnmCell const *cell_b = b;
 	int tmp;
 
 	tmp = cell_a->pos.row - cell_b->pos.row;
@@ -129,7 +129,7 @@ cb_compare_deps (gconstpointer a, gconstpointer b)
 }
 
 static void
-cb_collect_deps (Dependent *dep, gpointer user)
+cb_collect_deps (GnmDependent *dep, gpointer user)
 {
 	if (dependent_is_cell (dep)) {
 		GList **list = (GList **)user;
@@ -138,15 +138,15 @@ cb_collect_deps (Dependent *dep, gpointer user)
 }
 
 /**
- * cmd_select_cur_depends :
+ * sv_select_cur_depends :
  * @sv: The sheet
  *
  * Select all cells that depend on the expression in the current cell.
  */
 void
-cmd_select_cur_depends (SheetView *sv)
+sv_select_cur_depends (SheetView *sv)
 {
-	Cell  *cur_cell;
+	GnmCell  *cur_cell;
 	GList *deps = NULL, *ptr = NULL;
 
 	g_return_if_fail (IS_SHEET_VIEW (sv));
@@ -165,22 +165,22 @@ cmd_select_cur_depends (SheetView *sv)
 
 	/* Short circuit */
 	if (g_list_length (deps) == 1) {
-		Cell *cell = deps->data;
+		GnmCell *cell = deps->data;
 		sv_selection_add_pos (sv, cell->pos.col, cell->pos.row);
 	} else {
-		Range *cur = NULL;
+		GnmRange *cur = NULL;
 		ptr = NULL;
 
 		/* Merge the sorted list of cells into rows */
 		for (deps = g_list_sort (deps, &cb_compare_deps) ; deps ; ) {
-			Cell *cell = deps->data;
+			GnmCell *cell = deps->data;
 
 			if (cur == NULL ||
 			    cur->end.row != cell->pos.row ||
 			    cur->end.col+1 != cell->pos.col) {
 				if (cur)
 					ptr = g_list_prepend (ptr, cur);
-				cur = g_new (Range, 1);
+				cur = g_new (GnmRange, 1);
 				cur->start.row = cur->end.row = cell->pos.row;
 				cur->start.col = cur->end.col = cell->pos.col;
 			} else
@@ -194,11 +194,11 @@ cmd_select_cur_depends (SheetView *sv)
 		/* Merge the coalesced rows into ranges */
 		deps = ptr;
 		for (ptr = NULL ; deps ; ) {
-			Range *r1 = deps->data;
+			GnmRange *r1 = deps->data;
 			GList *fwd;
 
 			for (fwd = deps->next ; fwd ; ) {
-				Range *r2 = fwd->data;
+				GnmRange *r2 = fwd->data;
 
 				if (r1->start.col == r2->start.col &&
 				    r1->end.col == r2->end.col &&
@@ -216,7 +216,7 @@ cmd_select_cur_depends (SheetView *sv)
 
 		/* now select the ranges */
 		while (ptr) {
-			Range *r = ptr->data;
+			GnmRange *r = ptr->data;
 			sv_selection_add_range (sv,
 						r->start.col, r->start.row,
 						r->start.col, r->start.row,
@@ -229,16 +229,16 @@ cmd_select_cur_depends (SheetView *sv)
 }
 
 /**
- * cmd_select_cur_inputs :
+ * sv_select_cur_inputs :
  * @sv: The sheet
  *
  * Select all cells that are direct potential inputs to the
  * current cell.
  */
 void
-cmd_select_cur_inputs (SheetView *sv)
+sv_select_cur_inputs (SheetView *sv)
 {
-	Cell *cell;
+	GnmCell *cell;
 
 	g_return_if_fail (IS_SHEET_VIEW (sv));
 
@@ -269,27 +269,27 @@ cmd_select_cur_inputs (SheetView *sv)
  * Full undo support.
  */
 void
-cmd_paste (WorkbookControl *wbc, PasteTarget const *pt)
+cmd_paste (WorkbookControl *wbc, GnmPasteTarget const *pt)
 {
-	CellRegion  *content;
-	Range const *src_range;
+	GnmCellRegion  *content;
+	GnmRange const *src_range;
 
 	g_return_if_fail (pt != NULL);
 	g_return_if_fail (IS_SHEET (pt->sheet));
 
-	src_range = application_clipboard_area_get ();
-	content = application_clipboard_contents_get ();
+	src_range = gnm_app_clipboard_area_get ();
+	content = gnm_app_clipboard_contents_get ();
 
 	if (content == NULL && src_range != NULL) {
 		/* Pasting a Cut */
 		GnmExprRelocateInfo rinfo;
-		Sheet *src_sheet = application_clipboard_sheet_get ();
+		Sheet *src_sheet = gnm_app_clipboard_sheet_get ();
 
 		/* Validate the size & shape of the target here. */
 		int const cols = (src_range->end.col - src_range->start.col);
 		int const rows = (src_range->end.row - src_range->start.row);
 
-		Range dst = pt->range;
+		GnmRange dst = pt->range;
 
 		if (range_is_singleton (&dst)) {
 			dst.end.col = dst.start.col + cols;
@@ -303,7 +303,7 @@ cmd_paste (WorkbookControl *wbc, PasteTarget const *pt)
 				(dst.end.row - dst.start.row)+1,
 				(dst.end.col - dst.start.col)+1,
 				rows+1, cols+1);
-			gnumeric_error_invalid (COMMAND_CONTEXT (wbc),
+			gnm_cmd_context_error_invalid (GNM_CMD_CONTEXT (wbc),
 				_("Unable to paste into selection"), msg);
 			g_free (msg);
 			return;
@@ -316,7 +316,7 @@ cmd_paste (WorkbookControl *wbc, PasteTarget const *pt)
 		rinfo.target_sheet = pt->sheet;
 
 		if (!cmd_paste_cut (wbc, &rinfo, TRUE, NULL))
-			application_clipboard_clear (TRUE);
+			gnm_app_clipboard_clear (TRUE);
 
 	/* If this application has marked a selection use it */
 	} else if (content != NULL)
@@ -338,10 +338,10 @@ cmd_paste (WorkbookControl *wbc, PasteTarget const *pt)
 void
 cmd_paste_to_selection (WorkbookControl *wbc, SheetView *dest_sv, int paste_flags)
 {
-	Range const *r;
-	PasteTarget pt;
+	GnmRange const *r;
+	GnmPasteTarget pt;
 
-	if (!(r = selection_first_range (dest_sv, COMMAND_CONTEXT (wbc), _("Paste"))))
+	if (!(r = selection_first_range (dest_sv, GNM_CMD_CONTEXT (wbc), _("Paste"))))
 		return;
 
 	g_return_if_fail (r !=NULL);
