@@ -7,14 +7,14 @@
  * (C) 1999-2001 Jody Goldberg
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "command-context-priv.h"
 #include "ranges.h"
 
 #include <gsf/gsf-impl-utils.h>
 
-#define CC_CLASS(o) COMMAND_CONTEXT_CLASS (G_OBJECT_GET_CLASS (o))
+#define CC_CLASS(o) GNM_CMD_CONTEXT_CLASS (G_OBJECT_GET_CLASS (o))
 
 static GError *
 format_message (GQuark id, char const *message)
@@ -24,63 +24,63 @@ format_message (GQuark id, char const *message)
 }
 
 void
-cmd_context_error (CommandContext *context, GError *err)
+gnm_cmd_context_error (GnmCmdContext *context, GError *err)
 {
-	g_return_if_fail (IS_COMMAND_CONTEXT (context));
+	g_return_if_fail (IS_GNM_CMD_CONTEXT (context));
 	CC_CLASS (context)->error.error (context, err);
 }
 
 void
-gnumeric_error_error_info (CommandContext *context, ErrorInfo *error)
+gnm_cmd_context_error_info (GnmCmdContext *context, ErrorInfo *error)
 {
-	g_return_if_fail (IS_COMMAND_CONTEXT (context));
+	g_return_if_fail (IS_GNM_CMD_CONTEXT (context));
 	CC_CLASS (context)->error.error_info (context, error);
 }
 
 void
-gnumeric_error_system (CommandContext *context, char const *message)
+gnm_cmd_context_error_system (GnmCmdContext *context, char const *message)
 {
 	GError *err = format_message (gnm_error_system (), message);
-	cmd_context_error (context, err);
+	gnm_cmd_context_error (context, err);
 	g_error_free (err);
 }
 
 void
-gnumeric_error_read (CommandContext *context, char const *message)
+gnm_cmd_context_error_import (GnmCmdContext *context, char const *message)
 {
-	GError *err = format_message (gnm_error_read (), message);
-	cmd_context_error (context, err);
+	GError *err = format_message (gnm_error_import (), message);
+	gnm_cmd_context_error (context, err);
 	g_error_free (err);
 }
 
 void
-gnumeric_error_save (CommandContext *context, char const *message)
+gnm_cmd_context_error_export (GnmCmdContext *context, char const *message)
 {
-	GError *err = format_message (gnm_error_write (), message);
-	cmd_context_error (context, err);
+	GError *err = format_message (gnm_error_export (), message);
+	gnm_cmd_context_error (context, err);
 	g_error_free (err);
 }
 
 void
-gnumeric_error_invalid (CommandContext *context, char const *msg, char const *val)
+gnm_cmd_context_error_invalid (GnmCmdContext *context, char const *msg, char const *val)
 {
 	GError *err = g_error_new (gnm_error_invalid(), 0, "Invalid %s : '%s'", msg, val);
-	cmd_context_error (context, err);
+	gnm_cmd_context_error (context, err);
 	g_error_free (err);
 }
 
 void
-gnumeric_error_calc (CommandContext *context, char const *msg)
+gnm_cmd_context_error_calc (GnmCmdContext *context, char const *msg)
 {
 	GError *err = format_message (gnm_error_calc (), msg);
-	cmd_context_error (context, err);
+	gnm_cmd_context_error (context, err);
 	g_error_free (err);
 }
 
 void
-gnumeric_error_splits_array (CommandContext *context,
+gnm_cmd_context_error_splits_array (GnmCmdContext *context,
 			     G_GNUC_UNUSED char const *cmd,
-			     Range const *array)
+			     GnmRange const *array)
 {
 	GError *err;
 
@@ -90,7 +90,7 @@ gnumeric_error_splits_array (CommandContext *context,
 	else
 		err = g_error_new (gnm_error_array(), 0,
 			_("Would split an array"));
-	cmd_context_error (context, err);
+	gnm_cmd_context_error (context, err);
 }
 
 GQuark
@@ -102,19 +102,19 @@ gnm_error_system (void)
 	return quark;
 }
 GQuark
-gnm_error_read (void)
+gnm_error_import (void)
 {
 	static GQuark quark;
 	if (!quark)
-		quark = g_quark_from_static_string ("gnm_error_read");
+		quark = g_quark_from_static_string ("gnm_error_import");
 	return quark;
 }
 GQuark
-gnm_error_write (void)
+gnm_error_export (void)
 {
 	static GQuark quark;
 	if (!quark)
-		quark = g_quark_from_static_string ("gnm_error_write");
+		quark = g_quark_from_static_string ("gnm_error_export");
 	return quark;
 }
 GQuark
@@ -145,36 +145,37 @@ gnm_error_invalid (void)
 }
 
 void
-cmd_context_progress_set (CommandContext *context, gfloat f)
+cmd_context_progress_set (GnmCmdContext *context, gfloat f)
 {
-	g_return_if_fail (IS_COMMAND_CONTEXT (context));
+	g_return_if_fail (IS_GNM_CMD_CONTEXT (context));
 
 	CC_CLASS (context)->progress_set (context, f);
 }
 
 void
-cmd_context_progress_message_set (CommandContext *context, gchar const *msg)
+cmd_context_progress_message_set (GnmCmdContext *context, gchar const *msg)
 {
-	g_return_if_fail (IS_COMMAND_CONTEXT (context));
+	g_return_if_fail (IS_GNM_CMD_CONTEXT (context));
 
 	CC_CLASS (context)->progress_message_set (context, msg);
 }
 
 char *
-cmd_context_get_password (CommandContext *cc, char const *filename)
+gnm_cmd_context_get_password (GnmCmdContext *cc, char const *filename)
 {
-	g_return_val_if_fail (IS_COMMAND_CONTEXT (cc), NULL);
+	g_return_val_if_fail (IS_GNM_CMD_CONTEXT (cc), NULL);
 
 	return CC_CLASS (cc)->get_password (cc, filename);
 }
 
 void
-cmd_context_set_sensitive (CommandContext *cc, gboolean sensitive)
+gnm_cmd_context_set_sensitive (GnmCmdContext *cc, gboolean sensitive)
 {
-	g_return_if_fail (IS_COMMAND_CONTEXT (cc));
+	g_return_if_fail (IS_GNM_CMD_CONTEXT (cc));
 
 	CC_CLASS (cc)->set_sensitive (cc, sensitive);
 }
 
-GSF_CLASS (CommandContext, command_context,
-	   NULL, NULL, G_TYPE_OBJECT)
+GSF_CLASS (GnmCmdContext, gnm_cmd_context,
+	   NULL, NULL,
+	   G_TYPE_OBJECT)
