@@ -1,8 +1,8 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * lib.c
+ * goffice.c : a bogus little init file to pull all the parts together
  *
- * Copyright (C) 2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,7 +19,7 @@
  * USA
  */
 
-#include <gnumeric-config.h>
+#include <goffice/goffice-config.h>
 #include <goffice/goffice.h>
 #include <goffice/graph/gog-series.h>
 #include <goffice/graph/gog-plot.h>
@@ -31,6 +31,8 @@
 #include <goffice/graph/gog-label.h>
 #include <goffice/graph/gog-grid.h>
 #include <goffice/graph/gog-theme.h>
+#include <goffice/graph/gog-error-bar.h>
+#include <goffice/graph/go-data-simple.h>
 #include <goffice/utils/go-font.h>
 
 int goffice_graph_debug_level = 0;
@@ -50,6 +52,9 @@ libgoffice_init (void)
 	(void) GOG_AXIS_TYPE;
 	(void) GOG_LABEL_TYPE;
 	(void) GOG_GRID_TYPE;
+	(void) GOG_ERROR_BAR_TYPE;
+	(void) GO_DATA_SCALAR_VAL_TYPE;
+	(void) GO_DATA_SCALAR_STR_TYPE;
 	gog_themes_init	();
 }
 
