@@ -2,7 +2,7 @@
 /*
  * gog-axis.h : 
  *
- * Copyright (C) 2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -31,11 +31,15 @@ typedef enum {
 	GOG_AXIS_IN_MIDDLE = 0,
 	GOG_AXIS_AT_HIGH = 1
 } GogAxisPosition;
-typedef enum {
-	GOG_AXIS_TICK_LEVEL_NONE = 0,
-	GOG_AXIS_TICK_LEVEL_MAJOR,
-	GOG_AXIS_TICK_LEVEL_MINOR
-} GogAxisTickLevel;
+
+enum {
+	AXIS_ELEM_MIN = 0,
+	AXIS_ELEM_MAX,
+	AXIS_ELEM_MAJOR_TICK,
+	AXIS_ELEM_MINOR_TICK,
+	AXIS_ELEM_CROSS_POINT,
+	AXIS_ELEM_MAX_ENTRY
+};
 
 #define GOG_AXIS_TYPE	(gog_axis_get_type ())
 #define GOG_AXIS(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_AXIS_TYPE, GogAxis))
@@ -50,6 +54,8 @@ gboolean	gog_axis_get_bounds 	 (GogAxis const *axis,
 					  double *minima, double *maxima);
 void		gog_axis_get_ticks 	 (GogAxis const *axis,
 					  double *major, double *minor);
+GOData	       *gog_axis_get_labels	 (GogAxis const *axis,
+					  GogPlot **plot_that_labeled_axis);
 
 void 	      gog_axis_add_contributor	  (GogAxis *axis, GogObject *contrib);
 void 	      gog_axis_del_contributor	  (GogAxis *axis, GogObject *contrib);
