@@ -2,7 +2,7 @@
 /*
  * gog-chart-impl.h : implementation details for charts
  *
- * Copyright (C) 2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -33,7 +33,7 @@ struct _GogChart {
 	GogOutlinedObject	 base;
 
 	GSList  *plots;
-	unsigned full_cardinality, visible_cardinality;
+	unsigned cardinality;
 	gboolean cardinality_valid;
 
 	/* use a simple grid layout to position charts within graph */
