@@ -2,7 +2,7 @@
 /*
  * gog-chart.h :
  *
- * Copyright (C) 2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -39,10 +39,9 @@ void	  gog_chart_set_position  (GogChart *chart, unsigned x, unsigned y,
 				   unsigned cols, unsigned rows);
 
 void	  gog_chart_request_cardinality_update (GogChart *chart);
-void	  gog_chart_get_cardinality (GogChart *chart,
-				     unsigned *full, unsigned *visible);
-void	  gog_chart_foreach_elem    (GogChart *chart, gboolean only_visible,
-				     GogEnumFunc handler, gpointer data);
+unsigned  gog_chart_get_cardinality (GogChart *);
+void	  gog_chart_foreach_elem  (GogChart *,
+				   GogEnumFunc handler, gpointer data);
 
 gboolean  gog_chart_axis_set_is_valid (GogChart const *chart, GogAxisSet type);
 gboolean  gog_chart_axis_set_assign   (GogChart *chart, GogAxisSet type);
