@@ -2,7 +2,7 @@
 /*
  * gog-object-xml.c :
  *
- * Copyright (C) 2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,7 +19,7 @@
  * USA
  */
 
-#include <gnumeric-config.h>
+#include <goffice/goffice-config.h>
 #include <goffice/graph/gog-object-xml.h>
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-plot.h>
@@ -227,7 +227,8 @@ gog_object_write_property (GogObject *obj, GParamSpec *pspec, xmlNode *parent)
 				gog_persist_dom_save (GOG_PERSIST_DOM (val_obj), node);
 			} else
 				g_warning ("How are we supposed to persist this ??");
-		}
+		} else
+			success = FALSE;
 		break;
 
 	default:
@@ -395,4 +396,3 @@ gog_object_new_from_xml (GogObject *parent, xmlNode *node)
 	}
 	return res;
 }
-
