@@ -2,7 +2,7 @@
 /*
  * go-barcol.c
  *
- * Copyright (C) 2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,7 +19,7 @@
  * USA
  */
 
-#include <gnumeric-config.h>
+#include <goffice/goffice-config.h>
 #include "gog-barcol.h"
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
@@ -28,7 +28,7 @@
 #include <goffice/graph/go-data.h>
 #include <goffice/utils/go-color.h>
 
-#include <src/gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <src/mathfunc.h>
 #include <gsf/gsf-impl-utils.h>
 
@@ -123,7 +123,7 @@ gog_barcol_update_stacked_and_percentage (GogPlot1_5d *model,
 			if (i >= lengths[j])
 				continue;
 			tmp = vals[j][i];
-			if (!finitegnum (tmp))
+			if (!finite (tmp))
 				continue;
 			if (tmp > 0.)
 				pos_sum += tmp;
@@ -317,7 +317,7 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 				if (i >= lengths[j])
 					continue;
 				tmp = vals[j][i];
-				if (!finitegnum (tmp))
+				if (!finite (tmp))
 					continue;
 				if (tmp > 0.)
 					sum += tmp;
@@ -334,7 +334,7 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 			if (i >= lengths[j])
 				continue;
 			tmp = vals[j][i];
-			if (!finitegnum (tmp))
+			if (!finite (tmp))
 				continue;
 			tmp *= data_scale;
 			if (tmp >= 0.) {
