@@ -2,7 +2,7 @@
 /*
  * gog-line.c
  *
- * Copyright (C) 2003 Emmanuel Pacaud (emmanuel.pacaud@univ-poitiers.fr)
+ * Copyright (C) 2003-2004 Emmanuel Pacaud (emmanuel.pacaud@univ-poitiers.fr)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,7 +19,7 @@
  * USA
  */
 
-#include <gnumeric-config.h>
+#include <goffice/goffice-config.h>
 #include "gog-line.h"
 #include "gog-1.5d.h"
 #include <goffice/graph/gog-view.h>
@@ -30,7 +30,7 @@
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-marker.h>
 
-#include <src/gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <src/mathfunc.h>
 #include <gsf/gsf-impl-utils.h>
 
@@ -105,7 +105,7 @@ gog_line_update_stacked_and_percentage (GogPlot1_5d *model,
 			if (i >= lengths[j])
 				continue;
 			tmp = vals[j][i];
-			if (!finitegnum (tmp))
+			if (!finite (tmp))
 				continue;
 			sum += tmp;
 			abs_sum += fabs (tmp);
@@ -292,7 +292,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 
 		if (type == GOG_1_5D_AS_PERCENTAGE) {
 			for (i = 0; i < num_series; i++)
-				if (finitegnum (vals[i][j-1]))
+				if (finite (vals[i][j-1]))
 					abs_sum += fabs (vals[i][j-1]);
 			is_null = (gnumeric_sub_epsilon (abs_sum) <= 0.);
 		} else
@@ -302,7 +302,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			if (j > lengths[i])
 				continue;
 
-			value = (vals[i] && finitegnum (vals[i][j-1])) ? vals[i][j-1] : 0.0;
+			value = (vals[i] && finite (vals[i][j-1])) ? vals[i][j-1] : 0.0;
 			k = 2 * lengths[i] - j + 1;
 
 			if (is_area_plot && (type != GOG_1_5D_NORMAL)) {
