@@ -2,7 +2,7 @@
 /*
  * go-marker.c :
  *
- * Copyright (C) 2003 Emmanuel Pacaud (emmanuel.pacaud@univ-poitiers.fr)
+ * Copyright (C) 2003-2004 Emmanuel Pacaud (emmanuel.pacaud@univ-poitiers.fr)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -19,7 +19,11 @@
  * USA
  */
 
+#include <goffice/goffice-config.h>
 #include "go-marker.h"
+#include "go-color.h"
+#include <goffice/gui-utils/go-combo-color.h>
+#include <goffice/gui-utils/go-combo-pixmaps.h>
 
 #include <libart_lgpl/art_render_gradient.h>
 #include <libart_lgpl/art_render_svp.h>
@@ -29,18 +33,11 @@
 #include <libart_lgpl/art_affine.h>
 #include <libart_lgpl/art_rgb_svp.h>
 
-#include <goffice/utils/go-color.h>
-
-#include <gnumeric-config.h>
-#include <glade/glade-xml.h>
-#include <widgets/widget-color-combo.h>
-#include <widgets/widget-pixmap-combo.h>
-
-#include <gdk-pixbuf/gdk-pixdata.h>
-
 #include <src/mathfunc.h>
-#include <src/gnumeric-i18n.h>
 
+#include <glade/glade-xml.h>
+#include <gdk-pixbuf/gdk-pixdata.h>
+#include <glib/gi18n.h>
 #include <gsf/gsf-impl-utils.h>
 
 #define MARKER_DEFAULT_SIZE 5
@@ -218,7 +215,7 @@ typedef struct
 	ArtVpath const *fill_path;
 } MarkerShape;
 	
-static MarkerShape const marker_shapes[GO_MARKER_LAST] = {
+static MarkerShape const marker_shapes[GO_MARKER_MAX] = {
 	{ N_("none"),		NULL, NULL},
 	{ N_("square"),		square_path, square_path},
 	{ N_("diamond"),	diamond_path, diamond_path},
@@ -260,7 +257,18 @@ static struct {
 static GObjectClass *marker_parent_klass;
 
 static GdkPixbuf *
-marker_create_pixbuf_with_size (GOMarker * marker, guint size)
+new_blank_pixbuf (GOMarker *marker, guint size)
+{
+	int offset = ceil ((double)size * MARKER_OUTLINE_WIDTH / 2.0);
+	int pixbuf_size = size + 1 + 2 * offset;
+	GdkPixbuf *res = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
+					    pixbuf_size, pixbuf_size);
+	gdk_pixbuf_fill (res, 0);
+	return res;
+}
+
+static GdkPixbuf *
+marker_create_pixbuf_with_size (GOMarker *marker, guint size)
 {
 	double scaling[6], translation[6], affine[6];
 	guchar *pixels;
@@ -268,16 +276,16 @@ marker_create_pixbuf_with_size (GOMarker * marker, guint size)
 	ArtSVP *outline, *fill;
 	double half_size;
 	int pixbuf_size, offset;
-	ArtVpath * outline_path;
-	ArtVpath * fill_path;
-	GdkPixbuf * pixbuf;
+	ArtVpath  *outline_path;
+	ArtVpath  *fill_path;
+	GdkPixbuf *pixbuf;
 
-	if ((size < 1) ||
-	    (marker->shape == GO_MARKER_NONE))
+	if (size < 1 || marker->shape == GO_MARKER_NONE)
 		return NULL;
 
 	/* FIXME : markers look bad due to grey outline */
 
+	/* keep in sync with new_blank_pixbuf */
 	offset = ceil ((double)size * MARKER_OUTLINE_WIDTH / 2.0);
 	pixbuf_size = size + 1 + 2 * offset;
 	half_size = (double)size / 2.0;
@@ -345,8 +353,7 @@ go_marker_finalize (GObject *obj)
 		marker->pixbuf = NULL;
 	}
 	
-	if (marker_parent_klass->finalize)
-		marker_parent_klass->finalize (obj);
+	marker_parent_klass->finalize (obj);
 }
 
 static void
@@ -548,77 +555,47 @@ gpointer
 go_marker_selector (GOColor outline_color, GOColor fill_color,
 		    GOMarkerShape default_shape)
 {
-	static PixmapComboElement elements[] = {
-		{ NULL, NULL, GO_MARKER_NONE},
-		{ NULL, NULL, GO_MARKER_SQUARE },
-		{ NULL, NULL, GO_MARKER_DIAMOND},
-		{ NULL, NULL, GO_MARKER_TRIANGLE_DOWN},
-		{ NULL, NULL, GO_MARKER_TRIANGLE_UP},
-		{ NULL, NULL, GO_MARKER_TRIANGLE_RIGHT},
-		{ NULL, NULL, GO_MARKER_TRIANGLE_LEFT},
-		{ NULL, NULL, GO_MARKER_CIRCLE},
-		{ NULL, NULL, GO_MARKER_X},
-		{ NULL, NULL, GO_MARKER_CROSS},
-		{ NULL, NULL, GO_MARKER_ASTERISK},
-		{ NULL, NULL, GO_MARKER_BAR},
-		{ NULL, NULL, GO_MARKER_HALF_BAR},
-		{ NULL, NULL, GO_MARKER_BUTTERFLY},
-		{ NULL, NULL, GO_MARKER_HOURGLASS},
-		{ NULL, NULL, -1 } /* fill in with Auto */
+	static GOMarkerShape elements[] = {
+		GO_MARKER_NONE,		GO_MARKER_TRIANGLE_UP,	GO_MARKER_BUTTERFLY,
+		GO_MARKER_TRIANGLE_LEFT, GO_MARKER_DIAMOND,	GO_MARKER_TRIANGLE_RIGHT,
+		GO_MARKER_BAR,		GO_MARKER_TRIANGLE_DOWN, GO_MARKER_HOURGLASS,
+		GO_MARKER_HALF_BAR,	GO_MARKER_SQUARE,	GO_MARKER_CIRCLE,
+		GO_MARKER_X,		GO_MARKER_CROSS,	GO_MARKER_ASTERISK,
+		GO_MARKER_MAX /* fill with auto */
 	};
 
-	guint i, w, h,shape, length;
-	char const *shape_name;
-	gpointer data;
-	GdkPixdata pixdata;
-	GtkWidget *widget;
-	GdkPixbuf const *mbuf = NULL;
-	GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, 
-					    TRUE, 8, 
-					    SELECTOR_PIXBUF_SIZE, 
-					    SELECTOR_PIXBUF_SIZE);
-	GOMarker *marker = go_marker_new ();
+	unsigned	 i;
+	gboolean	 is_auto;
+	GOComboPixmaps	*w;
+	GOMarker	*marker = go_marker_new ();
+	GOMarkerShape	 shape;
+	GdkPixbuf const	*pixbuf;
 
 	go_marker_set_fill_color (marker, fill_color);
 	go_marker_set_outline_color (marker, outline_color);
 	go_marker_set_size (marker, 15);
 
+	w = go_combo_pixmaps_new (4);
 	for (i = 0; i < G_N_ELEMENTS (elements); i++) {
-		if (i == G_N_ELEMENTS (elements) -1) {
-			elements[i].id = -default_shape;
-			shape = default_shape;
-			shape_name = g_strdup_printf ("%s (%s)",
-				_("Automatic"), /* avoid violating string freeze */
-				marker_shapes [shape].name);
-		} else {
-			shape = elements[i].id;
-			shape_name = marker_shapes [shape].name;
-		}
-
-		go_marker_set_shape (marker, shape);
-		mbuf = go_marker_get_pixbuf (marker);
-		gdk_pixbuf_fill (pixbuf, 0); /* in case the fill colours have alpha = 0 */
-		if (mbuf != NULL)  {
-			w = gdk_pixbuf_get_width (mbuf);
-			h = gdk_pixbuf_get_height (mbuf);
-			gdk_pixbuf_copy_area (mbuf, 0, 0, w, h, pixbuf, 
-				(SELECTOR_PIXBUF_SIZE - w) / 2,
-				(SELECTOR_PIXBUF_SIZE - h) / 2);
-		}
-
-		data = gdk_pixdata_from_pixbuf (&pixdata, pixbuf, FALSE);
-		elements[i].inline_gdkpixbuf = gdk_pixdata_serialize (&pixdata, &length);
-		elements[i].untranslated_tooltip = shape_name;
-		g_free (data);
+		shape = elements[i];
+		is_auto = (shape == GO_MARKER_MAX);
+		go_marker_set_shape (marker, is_auto ? default_shape : shape);
+		pixbuf = go_marker_get_pixbuf (marker);
+		if (pixbuf == NULL) /* handle none */
+			pixbuf = new_blank_pixbuf (marker, marker->size);
+		else	/* add_element absorbs ref */
+			g_object_ref (G_OBJECT (pixbuf));
+		if (is_auto) {
+			/* xgettext : this will appear as 'Automatic (shapename)' */
+			char *name = g_strdup_printf (_("Automatic (%s)"),
+				_(marker_shapes [default_shape].name));
+			go_combo_pixmaps_add_element (w, pixbuf,
+				-default_shape, name);
+		} else
+			go_combo_pixmaps_add_element (w, pixbuf,
+				shape, _(marker_shapes [shape].name));
 	}
 	g_object_unref (marker);
-	g_object_unref (pixbuf);
 
-	widget = pixmap_combo_new (elements, 4, 4, TRUE);
-	for (i = 0; i < G_N_ELEMENTS (elements); i++)
-		g_free ((char *)elements[i].inline_gdkpixbuf);
-	gnm_combo_box_set_tearable (GNM_COMBO_BOX (widget), FALSE);
-
-	g_free ((char *)elements [i-1].untranslated_tooltip);
-	return widget;
+	return GTK_WIDGET (w);
 }
