@@ -21,8 +21,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
   **/
 
+#undef GTK_DISABLE_DEPRECATED
+#warning "This file uses GTK_DISABLE_DEPRECATED for GtkOptionMenu"
+#undef PANGO_DISABLE_DEPRECATED
+#warning "This file uses PANGO_DISABLE_DEPRECATED for pango_ft2_get_context"
+
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -32,9 +37,6 @@
 #include <sheet-merge.h>
 #include <sheet-style.h>
 #include <style-color.h>
-#include <widgets/widget-font-selector.h>
-#include <widgets/gnumeric-dashed-canvas-line.h>
-#include <widgets/gnumeric-combo-text.h>
 #include <gui-util.h>
 #include <selection.h>
 #include <str.h>
@@ -55,9 +57,12 @@
 #include <mathfunc.h>
 #include <preview-grid.h>
 #include <widgets/gnumeric-expr-entry.h>
-
+#include <widgets/widget-font-selector.h>
+#include <widgets/gnumeric-dashed-canvas-line.h>
+#include <widgets/gnumeric-combo-text.h>
 #include <widgets/widget-format-selector.h>
-
+#include <goffice/gui-utils/go-combo-color.h>
+#include <goffice/gui-utils/go-combo-box.h>
 #include <libart_lgpl/art_alphagamma.h>
 #include <libart_lgpl/art_pixbuf.h>
 #include <libart_lgpl/art_rgb_pixbuf_affine.h>
@@ -72,11 +77,12 @@
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtktextview.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtkbox.h>
 #include <libgnomecanvas/gnome-canvas-util.h>
 #include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
 #include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <pango/pangoft2.h>
-#include <widgets/widget-color-combo.h>
 
 static const struct {
 	const char *Cname;
@@ -343,20 +349,20 @@ setup_pattern_button (GladeXML  *gui,
 
 static void
 setup_color_pickers (ColorPicker *picker,
-	             char const *const color_group,
-	             char const *const container,
-		     char const *const default_caption,
-		     char const *const caption,
+	             char const *color_group,
+	             char const *container,
+	             char const *label,
+		     char const *default_caption,
+		     char const *caption,
 		     FormatState *state,
 		     GCallback preview_update,
-		     MStyleElementType const e,
+		     MStyleElementType e,
 		     GnmStyle	 *mstyle)
 {
-	GtkWidget *combo, *box, *frame;
-	ColorGroup *cg;
+	GtkWidget *combo, *w, *frame;
+	GOColorGroup *cg;
 	GnmColor *mcolor = NULL;
 	GnmColor *def_sc = NULL;
-	GdkColor *def_gc;
 
 	/* MSTYLE_ELEMENT_UNSET is abused as representing borders. */
 	if (e != MSTYLE_ELEMENT_UNSET &&
@@ -377,39 +383,35 @@ setup_color_pickers (ColorPicker *picker,
 	default:
 		g_warning ("Unhandled mstyle element!");
 	}
-	cg = color_group_fetch
-		(color_group,
+	cg = go_color_group_fetch (color_group,
 		 wb_control_view (WORKBOOK_CONTROL (state->wbcg)));
-
-	def_gc = def_sc ? &def_sc->color : &GTK_WIDGET (state->dialog)->style->black;
-
-	combo = color_combo_new (NULL, default_caption, def_gc, cg);
+	combo = go_combo_color_new (NULL, default_caption, 
+		def_sc ? GDK_TO_UINT (def_sc->color) : RGBA_BLACK, cg);
+	go_combo_box_set_title (GO_COMBO_BOX (combo), caption);
 	g_signal_connect (G_OBJECT (combo),
 		"color_changed",
 		G_CALLBACK (preview_update), state);
-	color_combo_set_instant_apply (COLOR_COMBO (combo), FALSE);
-	gnm_combo_box_set_tearable (GNM_COMBO_BOX (combo), FALSE);
-	/* FIXME: Should we disable the focus? Line 793 workbook-format-toolbar.c */
-	gnm_combo_box_set_title (GNM_COMBO_BOX (combo), caption);
 
 	/* Connect to the sample canvas and redraw it */
-
 	picker->combo          = combo;
 	picker->preview_update = preview_update;
 
 	if (mcolor && !mcolor->is_auto)
-		color_combo_set_color (COLOR_COMBO (combo), &mcolor->color);
+		go_combo_color_set_color (GO_COMBO_COLOR (combo), &mcolor->color);
 	else
-		color_combo_set_color_to_default (COLOR_COMBO (combo));
+		go_combo_color_set_color_to_default (GO_COMBO_COLOR (combo));
 
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
 	gtk_container_add (GTK_CONTAINER (frame), combo);
 
-	box = glade_xml_get_widget (state->gui, container);
-	gtk_box_pack_start (GTK_BOX (box), frame, FALSE, FALSE, 0);
+	w = glade_xml_get_widget (state->gui, container);
+	gtk_box_pack_start (GTK_BOX (w), frame, FALSE, FALSE, 0);
 	gtk_widget_show_all (frame);
 
+	w = glade_xml_get_widget (state->gui, label);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (w), combo);
+
 	if (def_sc)
 		style_color_unref (def_sc);
 }
@@ -911,8 +913,8 @@ cb_font_changed (G_GNUC_UNUSED GtkWidget *widget,
  * It is called whenever the color combo changes value.
  */
 static void
-cb_font_preview_color (G_GNUC_UNUSED ColorCombo *combo,
-		       GdkColor *c,
+cb_font_preview_color (G_GNUC_UNUSED GOComboColor *combo,
+		       GOColor c,
 		       G_GNUC_UNUSED gboolean is_custom,
 		       G_GNUC_UNUSED gboolean by_user,
 		       gboolean is_default, FormatState *state)
@@ -922,9 +924,9 @@ cb_font_preview_color (G_GNUC_UNUSED ColorCombo *combo,
 	if (!state->enable_edit)
 		return;
 
-	col = (is_default
+	col = is_default
 	       ? style_color_auto_font ()
-	       : style_color_new (c->red, c->green, c->blue));
+	       : style_color_new_go (c);
 	font_selector_set_color (state->font.selector, col);
 }
 
@@ -1016,6 +1018,9 @@ fmt_dialog_init_font_page (FormatState *state)
 		G_CALLBACK (cb_font_underline_changed), state);
 	gtk_widget_show_all (uline);
 
+	tmp = glade_xml_get_widget (state->gui, "underline_label");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (tmp), uline);
+
 	if (!mstyle_is_element_conflict (state->style, MSTYLE_FONT_STRIKETHROUGH))
 		strikethrough = mstyle_get_font_strike (state->style);
 
@@ -1057,8 +1062,8 @@ back_style_changed (FormatState *state)
 }
 
 static void
-cb_back_preview_color (G_GNUC_UNUSED ColorCombo *combo,
-		       GdkColor *c,
+cb_back_preview_color (G_GNUC_UNUSED GOComboColor *combo,
+		       GOColor c,
 		       G_GNUC_UNUSED gboolean is_custom,
 		       G_GNUC_UNUSED gboolean by_user,
 		       gboolean is_default,
@@ -1072,7 +1077,7 @@ cb_back_preview_color (G_GNUC_UNUSED ColorCombo *combo,
 		sc = style_color_auto_back ();
 		mstyle_set_pattern (state->back.style, 0);
 	} else {
-		sc = style_color_new (c->red, c->green, c->blue);
+		sc = style_color_new_go (c);
 		mstyle_set_pattern (state->back.style, state->back.pattern.cur_index);
 	}
 
@@ -1081,15 +1086,15 @@ cb_back_preview_color (G_GNUC_UNUSED ColorCombo *combo,
 }
 
 static void
-cb_pattern_preview_color (G_GNUC_UNUSED ColorCombo *combo,
-			  GdkColor *c,
+cb_pattern_preview_color (G_GNUC_UNUSED GOComboColor *combo,
+			  GOColor c,
 			  G_GNUC_UNUSED gboolean is_custom,
 			  G_GNUC_UNUSED gboolean by_user,
 			  gboolean is_default, FormatState *state)
 {
-	GnmColor *col = (is_default
+	GnmColor *col = is_default
 			   ? sheet_style_get_auto_pattern_color (state->sheet)
-			   : style_color_new (c->red, c->green, c->blue));
+			   : style_color_new_go (c);
 
 	mstyle_set_color (state->back.style, MSTYLE_COLOR_PATTERN, col);
 
@@ -1541,14 +1546,13 @@ cb_border_toggle (GtkToggleButton *button, BorderPicker *picker)
 }
 
 static void
-cb_border_color (G_GNUC_UNUSED ColorCombo *combo,
-		 GdkColor *c,
+cb_border_color (G_GNUC_UNUSED GOComboColor *combo,
+		 GOColor c,
 		 G_GNUC_UNUSED gboolean is_custom,
 		 G_GNUC_UNUSED gboolean by_user,
 		 gboolean is_default, FormatState *state)
 {
-	state->border.rgba =
-		GNOME_CANVAS_COLOR (c->red>>8, c->green>>8, c->blue>>8);
+	state->border.rgba = c;
 	state->border.is_auto_color = is_default;
 }
 
@@ -2274,22 +2278,22 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 			default_border_style);
 
 	setup_color_pickers (&state->border.color, "border_color_group",
-			     "border_color_hbox",
+			     "border_color_hbox",	"border_color_label",
 			     _("Automatic"), _("Border"), state,
 			     G_CALLBACK (cb_border_color),
 			     MSTYLE_ELEMENT_UNSET, state->style);
 	setup_color_pickers (&state->font.color, "fore_color_group",
-			     "font_color_hbox",
+			     "font_color_hbox",		"font_color_label",
 			     _("Automatic"), _("Foreground"), state,
 			     G_CALLBACK (cb_font_preview_color),
 			     MSTYLE_COLOR_FORE, state->style);
 	setup_color_pickers (&state->back.back_color, "back_color_group",
-			     "back_color_hbox",
+			     "back_color_hbox",		"back_color_label",
 			     _("Clear Background"), _("Background"), state,
 			     G_CALLBACK (cb_back_preview_color),
 			     MSTYLE_COLOR_BACK, state->style);
 	setup_color_pickers (&state->back.pattern_color, "pattern_color_group",
-			     "pattern_color_hbox",
+			     "pattern_color_hbox",	"pattern_color_label",
 			     _("Automatic"), _("Pattern"), state,
 			     G_CALLBACK (cb_pattern_preview_color),
 			     MSTYLE_COLOR_PATTERN, state->style);
@@ -2334,7 +2338,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	 * Set background to No colour.  This will set states correctly.
 	 */
 	if (!has_back)
-		color_combo_set_color_to_default (COLOR_COMBO (state->back.back_color.combo));
+		go_combo_color_set_color_to_default (GO_COMBO_COLOR (state->back.back_color.combo));
 
 	/* Setup the images in the border presets */
 	for (i = 0; (name = border_preset_buttons[i]) != NULL; ++i) {
