@@ -20,8 +20,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#undef GTK_DISABLE_DEPRECATED
+#warning "This file uses GTK_DISABLE_DEPRECATED for GtkOptionMenu"
+
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -36,6 +39,7 @@
 #include <selection.h>
 #include <widgets/gnumeric-expr-entry.h>
 #include <widgets/gnumeric-cell-renderer-expr-entry.h>
+#include <widgets/gnm-dao.h>
 #include <workbook-edit.h>
 #include <dao-gui-utils.h>
 #include <tools/dao.h>
@@ -225,14 +229,9 @@ static void
 dialog_set_button_sensitivity (G_GNUC_UNUSED GtkWidget *dummy,
 			       ConsolidateState *state)
 {
-	gboolean ready = FALSE;
-	int i = gnumeric_glade_group_value (state->base.gui, output_group);
+	gboolean ready;
 
-	ready = (i != 2) 
-		|| gnm_expr_entry_is_cell_ref 
-		(GNM_EXPR_ENTRY (state->base.output_entry), 
-		 state->base.sheet, TRUE);
-	ready = ready
+	ready = gnm_dao_is_ready (GNM_DAO (state->base.gdao))
 		&& (gtk_tree_model_iter_n_children
 		    (state->source_areas, NULL)> 2);
 	gtk_widget_set_sensitive (GTK_WIDGET (state->base.ok_button), ready);
@@ -560,7 +559,6 @@ dialog_consolidate (WorkbookControlGUI *wbcg)
 	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_CONSOLIDATE,
 			      "consolidate.glade", "Consolidate",
-			      NULL, NULL,
 			      _("Could not create the Consolidate dialog."),
 			      CONSOLIDATE_KEY,
 			      G_CALLBACK (cb_consolidate_ok_clicked), 
@@ -569,6 +567,7 @@ dialog_consolidate (WorkbookControlGUI *wbcg)
 			      0))
 		return;
 
+	gnm_dao_set_put (GNM_DAO (state->base.gdao), TRUE, TRUE);	
 	dialog_consolidate_tool_init (state);
 	gtk_widget_show (GTK_WIDGET (state->base.dialog));
 }
