@@ -19,6 +19,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
  */
+#undef GTK_DISABLE_DEPRECATED
+#warning "This file uses GTK_DISABLE_DEPRECATED for GtkOptionMenu"
 #include <gnumeric-config.h>
 #include <gnumeric.h>
 #include "dialogs.h"
@@ -36,7 +38,15 @@
 #include <sheet-style.h>
 #include <value.h>
 #include <workbook-edit.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
+
+#include <gtk/gtkbox.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtksizegroup.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkimagemenuitem.h>
+#include <gtk/gtkoptionmenu.h>
 #include <string.h>
 
 typedef struct {
@@ -110,7 +120,7 @@ dhl_get_target_cur_wb (HyperlinkState *state, gboolean *success)
 	GnmExprEntry *gee = state->internal_link_ee;
 	char const *target = gnm_expr_entry_get_text (gee);
 	Sheet *sheet = sc_sheet (state->sc);
-	Value *val;
+	GnmValue *val;
 
 	*success = FALSE;
 	if (strlen (target) == 0) {
@@ -119,7 +129,7 @@ dhl_get_target_cur_wb (HyperlinkState *state, gboolean *success)
 		val = gnm_expr_entry_parse_as_value (gee, sheet);
 		if (!val) {
 			/* not an address, is it a name ? */
-			ParsePos pp;
+			GnmParsePos pp;
 			GnmNamedExpr *nexpr;
 
 			parse_pos_init_sheet (&pp, sheet);
@@ -255,7 +265,7 @@ dhl_cb_cancel (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 static void
 dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 {
-	MStyle *style;
+	GnmStyle *style;
 	char *cmdname;
 	const char *target;
 	gboolean success;
@@ -425,7 +435,7 @@ dialog_hyperlink (WorkbookControlGUI *wbcg, SheetControl *sc)
 	if (gnumeric_dialog_raise_if_exists (wbcg, DIALOG_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
 		"hyperlink.glade", NULL, NULL);
         if (gui == NULL)
                 return;
