@@ -20,7 +20,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -37,6 +37,7 @@
 #include <command-context.h>
 
 #include <glade/glade.h>
+#include <gtk/gtkradiobutton.h>
 
 #define INSERT_CELL_DIALOG_KEY "insert-cells-dialog"
 
@@ -45,7 +46,7 @@ typedef struct {
 	GtkWidget          *dialog;
 	GtkWidget          *ok_button;
 	GtkWidget          *cancel_button;
-	Range const        *sel;
+	GnmRange const     *sel;
 	Sheet              *sheet;
 	GladeXML           *gui;
 } InsertCellState;
@@ -127,12 +128,12 @@ dialog_insert_cells (WorkbookControlGUI *wbcg)
 	InsertCellState *state;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	SheetView       *sv = wb_control_cur_sheet_view (wbc);
-	Range const *sel;
+	GnmRange const *sel;
 	int  cols, rows;
 
 	g_return_if_fail (wbcg != NULL);
 
-	if (!(sel = selection_first_range (sv, COMMAND_CONTEXT (wbc), _("Insert"))))
+	if (!(sel = selection_first_range (sv, GNM_CMD_CONTEXT (wbc), _("Insert"))))
 		return;
 	cols = sel->end.col - sel->start.col + 1;
 	rows = sel->end.row - sel->start.row + 1;
@@ -149,7 +150,7 @@ dialog_insert_cells (WorkbookControlGUI *wbcg)
 	if (gnumeric_dialog_raise_if_exists (wbcg, INSERT_CELL_DIALOG_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
 		"insert-cells.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
@@ -176,7 +177,7 @@ dialog_insert_cells (WorkbookControlGUI *wbcg)
 	g_signal_connect (G_OBJECT (state->cancel_button),
 		"clicked",
 		G_CALLBACK (cb_insert_cell_cancel_clicked), state);
-/* FIXME: Add correct helpfile address */
+
 	gnumeric_init_help_button (
 		glade_xml_get_widget (state->gui, "helpbutton"),
 		GNUMERIC_HELP_LINK_INSERT_CELS);
@@ -185,6 +186,12 @@ dialog_insert_cells (WorkbookControlGUI *wbcg)
 		"destroy",
 		G_CALLBACK (insert_cell_destroy), state);
 
+	gtk_toggle_button_set_active 
+		(GTK_TOGGLE_BUTTON (glade_xml_get_widget 
+				    (state->gui, cols < rows 
+				     ? "radio_0" : "radio_1")), 
+		 TRUE);
+
 	wbcg_edit_attach_guru (state->wbcg, state->dialog);
 	gnumeric_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
 			       INSERT_CELL_DIALOG_KEY);
