@@ -22,7 +22,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -38,7 +38,11 @@
 #include <value.h>
 #include <dao.h>
 #include "scenarios.h"
+
 #include <glade/glade.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkliststore.h>
 #include <string.h>
 
 typedef struct {
@@ -106,25 +110,27 @@ scenario_add_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	WorkbookControl         *wbc;
 	gchar                   *name;
 	gchar                   *comment;
-	Value                   *cell_range;
+	GnmValue                   *cell_range;
 	GtkWidget               *entry, *comment_view;
 	GtkTextBuffer           *buf;
 	GtkTextIter             start, end;
-	RangeRef                *rr;
+	GnmRangeRef const      *rr = NULL;
 	gboolean                res;
 	scenario_t              *scenario;
 
 	cell_range = gnm_expr_entry_parse_as_value
 		(GNM_EXPR_ENTRY (state->base.input_entry), state->base.sheet);
 
-	if (cell_range == NULL) {
+	if (cell_range != NULL)
+		rr = value_get_rangeref (cell_range);
+
+	if (rr == NULL) {
 		gnumeric_notice (state->base.wbcg, GTK_MESSAGE_ERROR,
 				 _("Invalid changing cells"));
 		gnm_expr_entry_grab_focus (state->base.input_entry, TRUE);
 		return;
 	}
 
-	rr = value_to_rangeref (cell_range, FALSE);
 	if (rr->a.sheet != state->base.sheet) {
 		gnumeric_notice (state->base.wbcg, GTK_MESSAGE_ERROR,
 				 _("Changing cells should be on the current "
@@ -179,7 +185,6 @@ scenario_add_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	gtk_widget_destroy (state->base.dialog);
  out:
 	value_release (cell_range);
-	g_free (rr);
 	return;
 }
 
@@ -220,7 +225,7 @@ dialog_scenario_add (WorkbookControlGUI *wbcg)
 	if (dialog_tool_init (&state->base, wbcg, wb_control_cur_sheet (wbc),
 			      GNUMERIC_HELP_LINK_SCENARIOS_ADD,
 			      "scenario-add.glade", "ScenarioAdd",
-			      _("_Changing cells:"), NULL, error_str,
+			      error_str,
 			      "ScenarioAdd",
 			      G_CALLBACK (scenario_add_ok_clicked_cb), NULL,
 			      G_CALLBACK (scenario_add_update_sensitivity_cb),
@@ -242,7 +247,8 @@ dialog_scenario_add (WorkbookControlGUI *wbcg)
 				  strlen (buf->str));
 	g_string_free (buf, FALSE);
 
-	state->base.output_entry = NULL;
+	state->base.gdao = NULL;
+
 	gnumeric_editable_enters (GTK_WINDOW (state->base.dialog),
 				  GTK_WIDGET (state->name_entry));
 	scenario_add_update_sensitivity_cb (NULL, state);
@@ -410,8 +416,8 @@ scenarios_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 
 	scenario_manager_ok (state->base.sheet);
 
-	gtk_widget_destroy (state->base.dialog);
 	scenario_manager_free (state);
+	gtk_widget_destroy (state->base.dialog);
 
 	return;
 }
@@ -450,7 +456,6 @@ scenarios_cancel_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 
 	restore_old_values (state);
 
-	gtk_widget_destroy (state->base.dialog);
 	wbc = WORKBOOK_CONTROL (state->base.wbcg);
 
 	/* Remove report sheets created on this dialog session. */
@@ -470,6 +475,7 @@ scenarios_cancel_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	scenario_recover_all (state->base.sheet->scenarios);
 
 	scenario_manager_free (state);
+	gtk_widget_destroy (state->base.dialog);
 }
 
 static void
@@ -642,7 +648,7 @@ dialog_scenarios (WorkbookControlGUI *wbcg)
 	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_SCENARIOS_VIEW,
 			      "scenario-manager.glade", "Scenarios",
-			      _("Results:"), NULL, error_str, "Scenarios",
+			      error_str, "Scenarios",
 			      G_CALLBACK (scenarios_ok_clicked_cb),
 			      G_CALLBACK (scenarios_cancel_clicked_cb),
 			      G_CALLBACK (scenarios_update_sensitivity_cb),
@@ -657,23 +663,16 @@ dialog_scenarios (WorkbookControlGUI *wbcg)
 	if (state->scenario_state->scenarios_treeview == NULL)
 	        goto error_out;
 
-	/* Set sensitivity of comment and changing cells widgets. */
-	w = glade_xml_get_widget (state->base.gui, "changing_cells_label");
-	if (w == NULL)
-	        goto error_out;
-	gtk_widget_set_sensitive (w, FALSE);
 	w = glade_xml_get_widget (state->base.gui, "changing_cells_entry");
 	if (w == NULL)
 	        goto error_out;
 	gtk_widget_set_sensitive (w, FALSE);
 	w = glade_xml_get_widget (state->base.gui, "comment_view");
+
 	if (w == NULL)
 	        goto error_out;
 	gtk_widget_set_sensitive (w, FALSE);
-	w = glade_xml_get_widget (state->base.gui, "comment_label");
-	if (w == NULL)
-	        goto error_out;
-	gtk_widget_set_sensitive (w, FALSE);
+
 	if (state->base.sheet->scenarios == NULL)
 		gtk_widget_set_sensitive
 			(state->scenario_state->summary_button, FALSE);
