@@ -20,7 +20,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -221,7 +221,7 @@ dialog_summary_update (WorkbookControlGUI *wbcg, gboolean open_dialog)
 	if (!open_dialog)
 		return;
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg), GLADE_FILE, NULL, NULL);
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg), GLADE_FILE, NULL, NULL);
 	if (gui == NULL)
 		return;
 
