@@ -66,11 +66,11 @@ void           style_format_ref		(GnmFormat *sf);
 void           style_format_unref	(GnmFormat *sf);
 gboolean       style_format_equal       (GnmFormat const *a, GnmFormat const *b);
 
-GnmFormat   *style_format_general		(void);
-GnmFormat   *style_format_default_date	(void);
-GnmFormat   *style_format_default_time	(void);
-GnmFormat   *style_format_default_percentage	(void);
-GnmFormat   *style_format_default_money	(void);
+GnmFormat *style_format_general		   (void);
+GnmFormat *style_format_default_date	   (void);
+GnmFormat *style_format_default_time	   (void);
+GnmFormat *style_format_default_percentage (void);
+GnmFormat *style_format_default_money	   (void);
 
 #define style_format_is_general(sf) ((sf)->family == FMT_GENERAL)
 #define style_format_is_text(sf) ((sf)->family == FMT_TEXT)
@@ -93,24 +93,22 @@ typedef struct {
 	int  left_spaces, left_req;
 	float scale;
 	gboolean rendered;
-	gboolean negative;
 	gboolean decimal_separator_seen;
-	gboolean supress_minus;
 	gboolean group_thousands;
 	gboolean has_fraction;
 } format_info_t;
 void render_number (GString *result, gnm_float number, format_info_t const *info);
 
 /* Locale support routines */
-void	    gnm_set_untranslated_bools (void);
-char const *gnm_setlocale           (int category, char const *val);
-char const *format_get_currency     (gboolean *precedes, gboolean *space_sep);
-gboolean    format_month_before_day (void);
-char        format_get_arg_sep      (void);
-char        format_get_col_sep      (void);
-char const *format_get_thousand     (void);
-char const *format_get_decimal      (void);
-char const *format_boolean          (gboolean b);
+void	       gnm_set_untranslated_bools (void);
+char const *   gnm_setlocale           (int category, char const *val);
+GString const *format_get_currency     (gboolean *precedes, gboolean *space_sep);
+gboolean       format_month_before_day (void);
+char           format_get_arg_sep      (void);
+char           format_get_col_sep      (void);
+GString const *format_get_thousand     (void);
+GString const *format_get_decimal      (void);
+char const *   format_boolean          (gboolean b);
 
 void number_format_init (void);
 void number_format_shutdown (void);
