@@ -9,7 +9,7 @@
  *    Miguel de Icaza (miguel@kernel.org)
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 
 #include "format.h"
@@ -189,7 +189,7 @@ void
 currency_date_format_init (void)
 {
 	gboolean precedes, space_sep;
-	char const *curr = format_get_currency (&precedes, &space_sep);
+	char const *curr = format_get_currency (&precedes, &space_sep)->str;
 	char *pre, *post, *pre_rep, *post_rep;
 	int err;
 
