@@ -7,7 +7,7 @@
  *     Jody Goldberg (jody@gnome.org)
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "gnumeric-canvas.h"
 
@@ -41,12 +41,12 @@ static FooCanvasClass *parent_klass;
 static gboolean
 gnm_canvas_guru_key (WorkbookControlGUI const *wbcg, GdkEventKey *event)
 {
-	GtkWidget *guru = wbcg_edit_has_guru (wbcg);
-	GtkWidget *entry = GTK_WIDGET (gnm_expr_entry_get_entry (wbcg_get_entry_logical (wbcg)));
+	GtkWidget *entry, *guru = wbcg_edit_get_guru (wbcg);
 
 	if (guru == NULL)
 		return FALSE;
 
+	entry = GTK_WIDGET (gnm_expr_entry_get_entry (wbcg_get_entry_logical (wbcg)));
 	gtk_widget_event ((entry != NULL) ? entry : guru, (GdkEvent *) event);
 	return TRUE;
 }
@@ -450,7 +450,7 @@ gnm_canvas_key_press (GtkWidget *widget, GdkEventKey *event)
 	if (scg->grab_stack > 0)
 		return TRUE;
 
-	if (wbcg_edit_has_guru (scg->wbcg) == NULL  &&
+	if (wbcg_edit_get_guru (scg->wbcg) == NULL  &&
 	    (scg->current_object != NULL || scg->new_object != NULL))
 		res = gnm_canvas_key_mode_object (gcanvas, event);
 	else {
@@ -1029,35 +1029,25 @@ gnm_canvas_slide_stop (GnmCanvas *gcanvas)
 static int
 col_scroll_step (int dx)
 {
-	if (dx <= 30)
-		return 1;
-	if (dx <= 60)
-		return 2;
-	if (dx <= 90)
-		return 4;
-	if (dx <= 120)
-		return 8;
-	return 16;
+	/* FIXME: get from gdk.  */
+	int dpi_x_this_screen = 90;
+	int start_x = dpi_x_this_screen / 3;
+	double double_dx = dpi_x_this_screen / 3.0;
+	double step = pow (2.0, (dx - start_x) / double_dx);
+
+	return (int) (CLAMP (step, 1.0, SHEET_MAX_COLS / 15.0));
 }
 
 static int
 row_scroll_step (int dy)
 {
-	if (dy <= 20)
-		return 1;
-	if (dy <= 30)
-		return 2;
-	if (dy <= 40)
-		return 4;
-	if (dy <= 45)
-		return 8;
-	if (dy <= 50)
-		return 16;
-	if (dy <= 60)
-		return 32;
-	if (dy <= 100)
-		return 500;
-	return 5000;
+	/* FIXME: get from gdk.  */
+	int dpi_y_this_screen = 90;
+	int start_y = dpi_y_this_screen / 4;
+	double double_dy = dpi_y_this_screen / 8.0;
+	double step = pow (2.0, (dy - start_y) / double_dy);
+
+	return (int) (CLAMP (step, 1.0, SHEET_MAX_ROWS / 15.0));
 }
 
 static gint
