@@ -6,7 +6,7 @@
  * Author:
  * 	Andreas J. Guelzow <aguelzow@taliesin.ca>
  *
- * (C) Copyright 2002 Andreas J. Guelzow <aguelzow@taliesin.ca>
+ * (C) Copyright 2002-2004 Andreas J. Guelzow <aguelzow@taliesin.ca>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,19 @@
 
 static GnmAppPrefs prefs;
 GnmAppPrefs const *gnm_app_prefs = &prefs;
+static GConfClient *gconf_client = NULL;
+
+GConfClient *
+gnm_app_get_gconf_client (void)
+{
+	if (!gconf_client) {
+		gconf_client = gconf_client_get_default ();
+		gconf_client_add_dir (gconf_client, "/apps/gnumeric",
+				      GCONF_CLIENT_PRELOAD_RECURSIVE,
+				      NULL);
+	}
+	return gconf_client;
+}
 
 static GConfValue *
 gnm_gconf_get (GConfClient *client, char const *key, GConfValueType t)
@@ -162,6 +175,17 @@ gnm_conf_init_essential (void)
 {
 	GConfClient *client = gnm_app_get_gconf_client ();
 
+	prefs.default_font.name = gconf_client_get_string (client,
+		CONF_DEFAULT_FONT_NAME, NULL);
+	if (prefs.default_font.name == NULL)
+		prefs.default_font.name = g_strdup (DEFAULT_FONT);
+	prefs.default_font.size = gnm_gconf_get_float (client,
+		CONF_DEFAULT_FONT_SIZE, 1., 100., DEFAULT_SIZE);
+	prefs.default_font.is_bold = gnm_gconf_get_bool (client,
+		CONF_DEFAULT_FONT_BOLD, FALSE);
+	prefs.default_font.is_italic = gnm_gconf_get_bool (client,
+		CONF_DEFAULT_FONT_ITALIC, FALSE);
+
 	prefs.file_history_max = gnm_gconf_get_int (client,
 		GNUMERIC_GCONF_FILE_HISTORY_N, 0, 20, 4);
 	prefs.file_history_files = gconf_client_get_list (client,
@@ -188,17 +212,64 @@ gnm_conf_init_essential (void)
 	prefs.zoom = gnm_gconf_get_float (client,
 		  GNUMERIC_GCONF_GUI_ZOOM, .1, 5., 1.);
 
+	/* Unfortunately we need the printing stuff in essentials since the */
+	/* first pi is created for the new sheet before the idle loop has a */
+	/* chance to run                                                    */
 	prefs.printer_config = gconf_client_get_string (client,
 		PRINTSETUP_GCONF_PRINTER_CONFIG, NULL);
+	prefs.print_center_horizontally = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_CENTER_HORIZONTALLY, FALSE); 
+	prefs.print_center_vertically = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_CENTER_VERTICALLY, FALSE);
+	prefs.print_grid_lines = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_PRINT_GRID_LINES, FALSE);
+	prefs.print_even_if_only_styles = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_EVEN_IF_ONLY_STYLES, FALSE);
+	prefs.print_black_and_white = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_PRINT_BLACK_AND_WHITE, FALSE);
+	prefs.print_titles = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_PRINT_TITLES, FALSE);
+	prefs.print_order_right_then_down = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_RIGHT_THEN_DOWN, FALSE);
+	prefs.print_scale_percentage = gnm_gconf_get_bool 
+		(client, PRINTSETUP_GCONF_SCALE_PERCENTAGE, TRUE);
+	prefs.print_scale_percentage_value = gnm_gconf_get_float 
+		(client, PRINTSETUP_GCONF_SCALE_PERCENTAGE_VALUE, 1, 100, 500);
+	prefs.print_scale_width = gnm_gconf_get_int 
+		(client, PRINTSETUP_GCONF_SCALE_WIDTH, 0, 100, 1);
+        prefs.print_scale_height = gnm_gconf_get_int 
+		(client, PRINTSETUP_GCONF_SCALE_HEIGHT, 0, 100, 1);
+	prefs.print_repeat_top = gconf_client_get_string (client,
+		PRINTSETUP_GCONF_REPEAT_TOP, NULL);
+	prefs.print_repeat_left = gconf_client_get_string (client,
+		PRINTSETUP_GCONF_REPEAT_LEFT, NULL);
+	prefs.print_tb_margins.top.points = gnm_gconf_get_float 
+		(client, PRINTSETUP_GCONF_MARGIN_TOP, 0.0, 10000.0, 120.0);
+	prefs.print_tb_margins.bottom.points = gnm_gconf_get_float 
+		(client, PRINTSETUP_GCONF_MARGIN_BOTTOM, 0.0, 10000.0, 120.0);
+	{
+		/* Note: the desired display unit is stored in the  */
+		/* printer config. So we are never using this field */
+		/* inside the margin structure, but only setting it */
+		/* in various input routines.                       */
+		prefs.print_tb_margins.top.desired_display 
+			= gnome_print_unit_get_by_abbreviation ("cm");
+		prefs.print_tb_margins.bottom.desired_display 
+			= prefs.print_tb_margins.top.desired_display;
+	}
+	prefs.print_all_sheets = gnm_gconf_get_bool (client,
+		PRINTSETUP_GCONF_ALL_SHEETS, TRUE);
 	prefs.printer_header = gconf_client_get_list (client,
 		PRINTSETUP_GCONF_HEADER, GCONF_VALUE_STRING, NULL);
 	prefs.printer_footer = gconf_client_get_list (client,
 		PRINTSETUP_GCONF_FOOTER, GCONF_VALUE_STRING, NULL);
+	prefs.printer_header_formats_left = gconf_client_get_list (client,
+		PRINTSETUP_GCONF_HEADER_FORMAT_LEFT, GCONF_VALUE_STRING, NULL);
+	prefs.printer_header_formats_middle = gconf_client_get_list (client,
+		PRINTSETUP_GCONF_HEADER_FORMAT_MIDDLE, GCONF_VALUE_STRING, NULL);
+	prefs.printer_header_formats_right = gconf_client_get_list (client,
+		PRINTSETUP_GCONF_HEADER_FORMAT_RIGHT, GCONF_VALUE_STRING, NULL);
 
-	prefs.auto_complete = gnm_gconf_get_bool (client,
-		GNUMERIC_GCONF_GUI_ED_AUTOCOMPLETE, TRUE);
-	prefs.live_scrolling = gnm_gconf_get_bool (client,
-		GNUMERIC_GCONF_GUI_ED_LIVESCROLLING, TRUE);
 }
 
 static gboolean
@@ -212,8 +283,12 @@ gnm_conf_init_extras (void)
 	prefs.recent_funcs = gconf_client_get_list (client,
 		FUNCTION_SELECT_GCONF_RECENT, GCONF_VALUE_STRING, NULL);
 
+	prefs.auto_complete = gnm_gconf_get_bool (client,
+		GNUMERIC_GCONF_GUI_ED_AUTOCOMPLETE, TRUE);
 	prefs.transition_keys = gnm_gconf_get_bool (client,
 		GNUMERIC_GCONF_GUI_ED_TRANSITION_KEYS, FALSE);
+	prefs.live_scrolling = gnm_gconf_get_bool (client,
+		GNUMERIC_GCONF_GUI_ED_LIVESCROLLING, TRUE);
 	prefs.recalc_lag = gnm_gconf_get_int (client,
 		GNUMERIC_GCONF_GUI_ED_RECALC_LAG, -5000, 5000, 200);
 	prefs.show_sheet_name = gnm_gconf_get_bool (client,
@@ -254,8 +329,6 @@ gnm_conf_init_extras (void)
 		GNUMERIC_GCONF_SORT_DEFAULT_ASCENDING, TRUE);
 	prefs.sort_max_initial_clauses = gnm_gconf_get_int (client,
 		GNUMERIC_GCONF_SORT_DIALOG_MAX_INITIAL, 0, 256, 10);
-	prefs.print_all_sheets = gnm_gconf_get_bool (client,
-		PRINTSETUP_GCONF_ALL_SHEETS, TRUE);
 	prefs.unfocused_range_selection = gnm_gconf_get_bool (client,
 		DIALOGS_GCONF_UNFOCUSED_RS, TRUE);
 	prefs.prefer_clipboard_selection = gnm_gconf_get_bool (client,
@@ -288,6 +361,11 @@ gnm_conf_shutdown (void)
 {
 	mstyle_unref (prefs.printer_decoration_font);
 	prefs.printer_decoration_font = NULL;
+	if (gconf_client) {
+		gconf_client_remove_dir (gconf_client, "/apps/gnumeric", NULL);
+		g_object_unref (G_OBJECT (gconf_client));
+		gconf_client = NULL;
+	}
 }
 
 void
@@ -640,6 +718,144 @@ gnm_gconf_set_printer_footer (gchar const *left, gchar const *middle,
 	prefs.printer_footer = list;
 }
 
+void     
+gnm_gconf_set_print_center_horizontally (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_CENTER_HORIZONTALLY,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_center_vertically (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_CENTER_VERTICALLY,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_grid_lines (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_PRINT_GRID_LINES,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_even_if_only_styles (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_EVEN_IF_ONLY_STYLES,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_black_and_white (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_PRINT_BLACK_AND_WHITE,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_titles (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_PRINT_TITLES,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_order_right_then_down (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_RIGHT_THEN_DOWN,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_scale_percentage (gboolean val)
+{
+	gconf_client_set_bool (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_SCALE_PERCENTAGE,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_scale_percentage_value (gnm_float val)
+{
+	gconf_client_set_float (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_SCALE_PERCENTAGE_VALUE,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_scale_width (gint val)
+{
+	gconf_client_set_int (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_SCALE_WIDTH,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_scale_height (gint val)
+{
+	gconf_client_set_int (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_SCALE_HEIGHT,
+			       val, NULL);
+}
+
+void     
+gnm_gconf_set_print_repeat_top (gchar const *str)
+{
+	gconf_client_set_string (gnm_app_get_gconf_client (),
+				 PRINTSETUP_GCONF_REPEAT_TOP,
+				 str, NULL);
+}
+
+void    
+gnm_gconf_set_print_repeat_left (gchar const *str)
+{
+	gconf_client_set_string (gnm_app_get_gconf_client (),
+				 PRINTSETUP_GCONF_REPEAT_LEFT,
+				 str, NULL);
+}
+
+void     
+gnm_gconf_set_print_tb_margins (PrintMargins const *pm)
+{
+	/* We are not saving the GnomePrintUnits since they are */
+	/* duplicated in the gnomeprintconfig                   */
+	gconf_client_set_float (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_MARGIN_TOP,
+			       pm->top.points, NULL);
+	gconf_client_set_float (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_MARGIN_BOTTOM,
+			       pm->bottom.points, NULL);
+}
+
+void     
+gnm_gconf_set_print_header_formats (GSList *left, GSList *middle, 
+				    GSList *right)
+{
+	gconf_client_set_list (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_HEADER_FORMAT_LEFT,
+			       GCONF_VALUE_STRING, left, NULL);
+	gconf_client_set_list (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_HEADER_FORMAT_MIDDLE,
+			       GCONF_VALUE_STRING, middle, NULL);
+	gconf_client_set_list (gnm_app_get_gconf_client (),
+			       PRINTSETUP_GCONF_HEADER_FORMAT_RIGHT,
+			       GCONF_VALUE_STRING, right, NULL);
+
+	g_slist_free_custom (left, g_free);
+	g_slist_free_custom (middle, g_free);
+	g_slist_free_custom (right, g_free);
+}
+
+
+
 /*  LATEX  */
 void
 gnm_gconf_set_latex_use_utf8 (gboolean val)
