@@ -479,7 +479,7 @@ gnm_pane_object_stop_editing (GnumericPane *pane)
 }
 
 #define CTRL_PT_SIZE		4
-#define CTRL_PT_OUTLINE		2
+#define CTRL_PT_OUTLINE		0
 /* space for 2 halves and a full */
 #define CTRL_PT_TOTAL_SIZE 	(CTRL_PT_SIZE*4 + CTRL_PT_OUTLINE*2)
 
@@ -587,21 +587,20 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event,
 	SheetControlGUI *scg = gcanvas->simple.scg;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (scg_get_wbcg (scg));
 
-	if (wbcg_edit_has_guru (scg_get_wbcg (scg)))
+	if (wbcg_edit_get_guru (scg_get_wbcg (scg)) != NULL)
 		return FALSE;
 
 	switch (event->type) {
-	case GDK_ENTER_NOTIFY: {
-		GdkCursorType ct = GPOINTER_TO_UINT
-			(g_object_get_data (G_OBJECT (ctrl_pt), "cursor"));
-		gnm_widget_set_cursor_type (GTK_WIDGET (ctrl_pt->canvas), ct);
+	case GDK_ENTER_NOTIFY:
+		gnm_widget_set_cursor_type (GTK_WIDGET (ctrl_pt->canvas),
+			GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (ctrl_pt), "cursor")));
 
 		if (pane->control_points [8] != ctrl_pt)
 			foo_canvas_item_set (ctrl_pt,
 				"fill_color",    "green",
 				NULL);
 		break;
-	}
+
 	case GDK_LEAVE_NOTIFY:
 		scg_set_display_cursor (scg);
 		if (pane->control_points [8] != ctrl_pt)
@@ -611,7 +610,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event,
 		break;
 
 	case GDK_BUTTON_RELEASE:
-		if (pane->drag_object != so)
+		if (pane->drag_object != so || event->button.button != 1)
 			return FALSE;
 
 		cmd_object_move (wbc, so, &scg->old_anchor,
@@ -619,11 +618,14 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event,
 		gnm_canvas_slide_stop (gcanvas);
 		pane->drag_object = NULL;
 		gnm_simple_canvas_ungrab (ctrl_pt, event->button.time);
+		gnm_widget_set_cursor_type (GTK_WIDGET (ctrl_pt->canvas),
+			GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (ctrl_pt), "cursor")));
 		sheet_object_update_bounds (so, NULL);
 		break;
 
 	case GDK_BUTTON_PRESS:
-		gnm_canvas_slide_stop (gcanvas);
+		if (pane->drag_object != NULL)
+			return FALSE;
 
 		switch (event->button.button) {
 		case 1:
@@ -637,6 +639,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event,
 			scg->last_x = event->button.x;
 			scg->last_y = event->button.y;
 			gnm_canvas_slide_init (gcanvas);
+			gnm_widget_set_cursor_type (GTK_WIDGET (ctrl_pt->canvas), GDK_HAND2);
 			break;
 
 		case 3: display_object_menu (so, so_view, event);
@@ -702,7 +705,7 @@ new_control_point (GObject *so_view, int idx, double x, double y,
 
 	item = foo_canvas_item_new (
 		gcanvas->object_group,
-		FOO_TYPE_CANVAS_RECT,
+		FOO_TYPE_CANVAS_ELLIPSE,
 		"outline_color", "black",
 		"fill_color",    "white",
 		"width_pixels",  CTRL_PT_OUTLINE,
@@ -762,16 +765,21 @@ set_acetate_coords (GnumericPane *pane, GObject *so_view,
 	b += (CTRL_PT_SIZE + CTRL_PT_OUTLINE) / 2;
 
 	if (pane->control_points [8] == NULL) {
-		static char diagonal [] = { 0xcc, 0x66, 0x33, 0x99, 0xcc, 0x66, 0x33, 0x99 };
+#undef WITH_STIPPLE_BORDER /* not so pretty */
+#ifdef WITH_STIPPLE_BORDER
+		static char const diagonal [] = { 0xcc, 0x66, 0x33, 0x99, 0xcc, 0x66, 0x33, 0x99 };
 		GdkBitmap *stipple = gdk_bitmap_create_from_data (GTK_WIDGET (gcanvas)->window,
 								  diagonal, 8, 8);
+#endif
 		FooCanvasItem *item = foo_canvas_item_new (
 			gcanvas->object_group,
 			item_acetate_get_type (),
 			"fill_color",		NULL,
-			"width_pixels",		CTRL_PT_SIZE + CTRL_PT_OUTLINE,
+#ifdef WITH_STIPPLE_BORDER
+			"width_units",		(double)(CTRL_PT_SIZE + CTRL_PT_OUTLINE),
 			"outline_color",	"black",
 			"outline_stipple",	stipple,
+#endif
 #if 0
 			/* work around the screwup in canvas-item-shape that adds a large
 			 * border to anything that uses miter (required for gnome-canvas
@@ -779,7 +787,9 @@ set_acetate_coords (GnumericPane *pane, GObject *so_view,
 			"join_style",		GDK_JOIN_ROUND,
 #endif
 			NULL);
+#ifdef WITH_STIPPLE_BORDER
 		g_object_unref (stipple);
+#endif
 		g_signal_connect (G_OBJECT (item),
 				  "event",
 				  G_CALLBACK (cb_control_point_event), so_view);
@@ -875,6 +885,7 @@ cb_sheet_object_canvas_event (FooCanvasItem *item, GdkEvent *event,
 			scg->last_x = event->button.x;
 			scg->last_y = event->button.y;
 			gnm_canvas_slide_init (GNM_CANVAS (item->canvas));
+			gnm_widget_set_cursor_type (GTK_WIDGET (item->canvas), GDK_HAND2);
 		} else
 			display_object_menu (so, item, event);
 		break;
