@@ -85,6 +85,7 @@ char *    gnumeric_usr_plugin_dir (void);
 
 void      gnm_strescape (GString *target, char const *string);
 char const *gnm_strunescape (GString *target, char const *string);
+void      gnm_string_append_gstring (GString *target, const GString *source);
 
 char *    gnumeric_utf8_strcapital (char const *p, ssize_t len);
 
@@ -94,5 +95,6 @@ gpointer     gnm_mem_chunk_alloc	(GnmMemChunk *);
 gpointer     gnm_mem_chunk_alloc0	(GnmMemChunk *);
 void         gnm_mem_chunk_free		(GnmMemChunk *, gpointer);
 void         gnm_mem_chunk_foreach_leak (GnmMemChunk *, GFunc, gpointer);
+const char*  gnm_get_real_name          (void);
 
 #endif /* GNUMERIC_UTILS_H */
