@@ -1,8 +1,8 @@
-/* vim: set sw=8: */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * item-edit.c : Edit facilities for worksheets.
  *
- * (C) 1999-2002 Miguel de Icaza & Jody Goldberg
+ * (C) 1999-2004 Miguel de Icaza & Jody Goldberg
  *
  * This module provides:
  *   * Integration of an in-sheet text editor (GtkEntry) with the Workbook
@@ -11,9 +11,8 @@
  *   * Feedback on expressions in the spreadsheet (referenced cells or
  *     ranges are highlighted on the spreadsheet).
  */
-
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "item-edit.h"
 
@@ -53,12 +52,12 @@ struct _ItemEdit {
 	PangoLayout	*layout;
 
 	/* Where are we */
-	GnmCellPos	   pos;
+	GnmCellPos pos;
 	gboolean   cursor_visible;
 	int        blink_timer;
 
-	GnmFont *gfont;
-	GnmStyle	  *style;
+	GnmFont   *gfont;
+	GnmStyle  *style;
 	GdkGC     *fill_gc;	/* Default background fill gc */
 
 	/* When editing, if the cursor is inside a cell name, or a cell range,
@@ -108,11 +107,11 @@ ie_scan_for_range (ItemEdit *ie)
 				if (ie->feedback_cursor[i] == NULL)
 					ie->feedback_cursor[i] = foo_canvas_item_new (
 						FOO_CANVAS_GROUP (FOO_CANVAS (pane->gcanvas)->root),
-						item_cursor_get_type (),
-						"SheetControlGUI",	ie->scg,
-						"style",		ITEM_CURSOR_BLOCK,
-						"color",		"blue",
-						NULL);
+					item_cursor_get_type (),
+					"SheetControlGUI",	ie->scg,
+					"style",		ITEM_CURSOR_BLOCK,
+					"color",		"blue",
+					NULL);
 				item_cursor_bound_set (ITEM_CURSOR (ie->feedback_cursor[i]), &range);
 			});
 			return;
@@ -199,45 +198,11 @@ item_edit_point (FooCanvasItem *item, double c_x, double c_y, int cx, int cy,
 static int
 item_edit_event (FooCanvasItem *item, GdkEvent *event)
 {
+	/* FIXME : Handle mouse events here */
 	switch (event->type){
 	case GDK_ENTER_NOTIFY:
 		gnm_widget_set_cursor_type (GTK_WIDGET (item->canvas), GDK_XTERM);
 		return TRUE;
-
-	case GDK_BUTTON_PRESS:
-		if (event->button.button == 1) {
-			ItemEdit *ie = ITEM_EDIT (item);
-			GtkEditable *ed = GTK_EDITABLE (ie->entry);
-			double x = event->button.x, y = event->button.y;
-			int target_index, trailing;
-
-			x -= MIN (item->x1, item->x2);
-			y -= MIN (item->y1, item->y2);
-
-			if (pango_layout_xy_to_index (ie->layout,
-						      x * PANGO_SCALE, y * PANGO_SCALE,
-						      &target_index, &trailing)) {
-				int preedit = GNM_CANVAS (item->canvas)->preedit_length;
-				char const *text = pango_layout_get_text (ie->layout);
-				gint cur_index = gtk_editable_get_position (ed);
-				cur_index = g_utf8_offset_to_pointer (text, cur_index) - text;
-
-				if (target_index >= cur_index && preedit > 0) {
-					if (target_index < (cur_index + preedit)) {
-						target_index = cur_index;
-						trailing = 0;
-					} else
-						target_index -= preedit;
-				}
-				gtk_editable_set_position (GTK_EDITABLE (ie->entry),
-					g_utf8_pointer_to_offset (text, text + target_index)
-					+ trailing);
-
-				return TRUE;
-			}
-		}
-		break;
-
 	default :
 		break;
 	}
@@ -273,19 +238,13 @@ ie_layout (FooCanvasItem *item)
 	pango_layout_set_wrap (ie->layout, PANGO_WRAP_CHAR);
 	pango_layout_set_width (ie->layout, (int)(item->x2 - item->x1)*PANGO_SCALE);
 
- 	attrs = pango_attr_list_new ();
-	pango_layout_set_attributes (ie->layout, attrs);
-	pango_attr_list_unref (attrs);
+	attrs = wbcg_edit_get_markup (scg_get_wbcg (ie->scg), TRUE);
+	if (attrs != NULL)
+		attrs = pango_attr_list_copy (attrs);
+	else
+		attrs = mstyle_generate_attrs_full (ie->style);
 
-	{
-		GnmColor *fore = mstyle_get_color (ie->style, MSTYLE_COLOR_FORE);
-		attr = pango_attr_foreground_new (fore->color.red,
-						  fore->color.green,
-						  fore->color.blue);
-		attr->start_index = 0;
-		attr->end_index = -1;
-		pango_attr_list_insert (attrs, attr);
-	}
+	/* reverse video the auto completion text  */
 	if (entered_text != NULL && entered_text != text) {
 		GnmColor *color;
 		int const start = strlen (entered_text);
@@ -304,31 +263,11 @@ ie_layout (FooCanvasItem *item)
 		attr->end_index = G_MAXINT;
 		pango_attr_list_insert (attrs, attr);
 	}
-	/* Handle underlining and strikethrough */
-	switch (mstyle_get_font_uline (ie->style)) {
-	case UNDERLINE_SINGLE :
-		attr = pango_attr_underline_new (PANGO_UNDERLINE_SINGLE);
-		attr->start_index = 0;
-		attr->end_index = -1;
-		pango_attr_list_insert (attrs, attr);
-		break;
+	pango_layout_set_attributes (ie->layout, attrs);
+	pango_attr_list_unref (attrs);
 
-	case UNDERLINE_DOUBLE :
-		attr = pango_attr_underline_new (PANGO_UNDERLINE_DOUBLE);
-		attr->start_index = 0;
-		attr->end_index = -1;
-		pango_attr_list_insert (attrs, attr);
-		break;
+	text = wbcg_edit_get_display_text (scg_get_wbcg (ie->scg));
 
-	default :
-		break;
-	};
-	if (mstyle_get_font_strike (ie->style)){
-		attr = pango_attr_strikethrough_new (TRUE);
-		attr->start_index = 0;
-		attr->end_index = -1;
-		pango_attr_list_insert (attrs, attr);
-	}
 	if (GNM_CANVAS (canvas)->preedit_length) {
 		PangoAttrList *tmp_attrs = pango_attr_list_new ();
 		pango_attr_list_splice (tmp_attrs, GNM_CANVAS (canvas)->preedit_attrs,
@@ -434,7 +373,7 @@ cb_item_edit_cursor_blink (ItemEdit *ie)
 
 	ie->cursor_visible = !ie->cursor_visible;
 
-	foo_canvas_item_request_redraw (item);
+	foo_canvas_item_request_update (item);
 	return TRUE;
 }
 
@@ -495,9 +434,8 @@ item_edit_init (ItemEdit *ie)
  * We use this to sync up the GtkEntry with our display on the screen.
  */
 static void
-entry_changed (GnmExprEntry *ignore, void *data)
+entry_changed (FooCanvasItem *item)
 {
-	FooCanvasItem *item = FOO_CANVAS_ITEM (data);
 	ItemEdit *ie = ITEM_EDIT (item);
 	char const *text = gtk_entry_get_text (ie->entry);
 
@@ -526,25 +464,20 @@ item_edit_finalize (GObject *gobject)
 		ie->style= NULL;
 	}
 
-	if (G_OBJECT_CLASS (parent_class)->finalize)
-		(G_OBJECT_CLASS (parent_class)->finalize) (gobject);
+	(G_OBJECT_CLASS (parent_class)->finalize) (gobject);
 }
 
 static int
-entry_event (GtkEntry *entry, GdkEvent *event, FooCanvasItem *item)
+entry_key_press (FooCanvasItem *item)
 {
-	entry_changed (NULL, item);
+	entry_changed (item);
 	return TRUE;
 }
 
 static int
-entry_cursor_event (GtkEntry *entry, GParamSpec *pspec, FooCanvasItem *item)
+entry_cursor_event (FooCanvasItem *item)
 {
-	/* ensure we draw a cursor when moving quickly no matter what the
-	 * current state is */
-	ITEM_EDIT (item)->cursor_visible = TRUE;
-
-	entry_changed (NULL, item);
+	entry_changed (item);
 	return TRUE;
 }
 
@@ -567,15 +500,18 @@ item_edit_set_property (GObject *gobject, guint param_id,
 	sv = sc_view (SHEET_CONTROL (ie->scg));
 	ie->pos = sv->edit_pos;
 	ie->entry = entry = wbcg_get_entry (scg_get_wbcg (ie->scg));
+	g_signal_connect_object (G_OBJECT (scg_get_wbcg (ie->scg)),
+		"markup-changed",
+		G_CALLBACK (foo_canvas_item_request_update), G_OBJECT (ie), G_CONNECT_SWAPPED);
 	g_signal_connect_object (G_OBJECT (gtk_widget_get_parent (GTK_WIDGET (entry))),
 		"changed",
-		G_CALLBACK (entry_changed), G_OBJECT (ie), 0);
+		G_CALLBACK (entry_changed), G_OBJECT (ie), G_CONNECT_SWAPPED);
 	g_signal_connect_object (G_OBJECT (entry),
 		"key-press-event",
-		G_CALLBACK (entry_event), G_OBJECT (ie), G_CONNECT_AFTER);
+		G_CALLBACK (entry_key_press), G_OBJECT (ie), G_CONNECT_AFTER|G_CONNECT_SWAPPED);
 	g_signal_connect_object (G_OBJECT (entry),
 		"notify::cursor-position",
-		G_CALLBACK (entry_cursor_event), G_OBJECT (ie), G_CONNECT_AFTER);
+		G_CALLBACK (entry_cursor_event), G_OBJECT (ie), G_CONNECT_AFTER|G_CONNECT_SWAPPED);
 
 	ie_scan_for_range (ie);
 
