@@ -127,8 +127,7 @@ item_grid_finalize (GObject *object)
 	ig_clear_hlink_tip (ig);
 	ig->cur_link = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->finalize)
-		(*G_OBJECT_CLASS (parent_class)->finalize) (object);
+	(*G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
 static void
@@ -282,11 +281,6 @@ item_grid_draw_background (GdkDrawable *drawable, ItemGrid *ig,
 					    ig->canvas_item.canvas,
 					    is_selected);
 
-#if DEBUG_SELECTION_PAINT
-	if (is_selected) {
-		fprintf (stderr, "x = %d, w = %d\n", x, w+1);
-	}
-#endif
 	if (has_back || is_selected)
 		/* Fill the entire cell (API excludes far pixel) */
 		gdk_draw_rectangle (drawable, gc, TRUE, x, y, w+1, h+1);
@@ -411,9 +405,6 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 		 * Reinverting list to maintain the original order */
 		g_return_if_fail (merged_active == NULL);
 
-#if DEBUG_SELECTION_PAINT
-		fprintf (stderr, "row = %d (startcol = %d)\n", row, start_col);
-#endif
 		while (merged_active_seen != NULL) {
 			GSList *tmp = merged_active_seen->next;
 			merged_active_seen->next = merged_active;
@@ -482,9 +473,6 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 			CellSpanInfo const *span;
 			ColRowInfo const *ci = sheet_col_get_info (sheet, col);
 
-#if DEBUG_SELECTION_PAINT
-			fprintf (stderr, "col [%d] = %d\n", col, x);
-#endif
 			if (!ci->visible) {
 				if (merged_active != NULL) {
 					GnmRange const *r = merged_active->data;
@@ -522,7 +510,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 
 						/* in case something managed the bottom of a merge */
 						if (r->end.row < row)
-							goto plain_draw;
+							continue;
 					} else {
 						ptr->next = merged_active_seen;
 						merged_active_seen = ptr;
@@ -558,7 +546,6 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 				}
 			}
 
-plain_draw : /* a quick hack to deal with 142267 */
 			style = sr.styles [col];
 			item_grid_draw_background (drawable, ig,
 				style, col, row, x, y,
@@ -903,11 +890,10 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	/* If we are not configuring an object then clicking on the sheet
 	 * ends the edit.
 	 */
-	if (scg->current_object != NULL) {
-		if (!wbcg_edit_has_guru (scg->wbcg))
-			scg_mode_edit (sc);
-	} else
+	if (scg->current_object == NULL)
 		wbcg_focus_cur_scg (scg->wbcg);
+	else if (wbcg_edit_get_guru (scg->wbcg) == NULL)
+		scg_mode_edit (sc);
 
 	/* If we were already selecting a range of cells for a formula,
 	 * reset the location to a new place, or extend the selection.
@@ -939,7 +925,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	}
 
 	/* While a guru is up ignore clicks */
-	if (wbcg_edit_has_guru (scg->wbcg))
+	if (wbcg_edit_get_guru (scg->wbcg) != NULL)
 		return TRUE;
 
 	/* This was a regular click on a cell on the spreadsheet.  Select it.
