@@ -17,13 +17,15 @@
  */
 
 #include <gnumeric-config.h>
+
+#ifdef WITH_GNOME
 #include "gnumeric.h"
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <glib.h>
 #include "session.h"
 #include "application.h"
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <workbook.h>
 #include <workbook-priv.h>
 #include <workbook-view.h>
@@ -38,18 +40,19 @@ static GnomeClient *master_client = NULL;
 static const char *program_argv0 = NULL;
 static const char *current_dir = NULL;
 
-static void set_clone_restart (GnomeClient *client)
+static void
+set_clone_restart (GnomeClient *client)
 {
 	GList *ptr, *workbooks;
 	char **argv;
 	int count = 1;
 
 	argv = g_new0 (char *, 
-		       2 + g_list_length (application_workbook_list ()));
+		       2 + g_list_length (gnm_app_workbook_list ()));
 
 	argv[0] = (char *) program_argv0;
 
-	workbooks = g_list_copy (application_workbook_list ());
+	workbooks = g_list_copy (gnm_app_workbook_list ());
 	for (ptr = workbooks; ptr != NULL ; ptr = ptr->next) {
 		Workbook *wb = ptr->data;
 		if (wb->file_format_level == FILE_FL_AUTO) {
@@ -71,7 +74,7 @@ interaction_function (GnomeClient *client, gint key, GnomeDialogType dialog_type
 	gboolean ask_user = TRUE;
 	gboolean do_not_cancel = FALSE;
 
-	workbooks = g_list_copy (application_workbook_list ());
+	workbooks = g_list_copy (gnm_app_workbook_list ());
 	for (ptr = workbooks; ptr != NULL ; ptr = ptr->next) {
 		Workbook *wb = ptr->data;
 		WorkbookControlGUI *wbcg = NULL;
@@ -129,13 +132,19 @@ interaction_function (GnomeClient *client, gint key, GnomeDialogType dialog_type
 						    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 			gtk_dialog_add_button (GTK_DIALOG(d), GTK_STOCK_SAVE, GTK_RESPONSE_YES);
 			gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
+
+#warning We are making these windows sticky to work around a session manager bug that may make them inaccessible
+			gtk_window_stick (GTK_WINDOW (wbcg_toplevel (wbcg)));
+			gtk_window_stick (GTK_WINDOW (d));
 			
 			button = gnumeric_dialog_run (wbcg, GTK_DIALOG (d));
+
 			g_free (msg);
 			
 			switch (button) {
 			case GTK_RESPONSE_YES:
 				if (!gui_file_save (wbcg, wb_view)) {
+					gtk_window_unstick (GTK_WINDOW (wbcg_toplevel (wbcg)));
 					do_not_cancel = TRUE;
 					goto finished;
 				}
@@ -143,6 +152,7 @@ interaction_function (GnomeClient *client, gint key, GnomeDialogType dialog_type
 				
 			case (- GTK_RESPONSE_YES):
 				if (!gui_file_save (wbcg, wb_view)) {
+					gtk_window_unstick (GTK_WINDOW (wbcg_toplevel (wbcg)));
 					do_not_cancel = TRUE;
 					goto finished;
 				}
@@ -153,14 +163,17 @@ interaction_function (GnomeClient *client, gint key, GnomeDialogType dialog_type
 				break;
 				
 			case (- GTK_RESPONSE_NO):
+				gtk_window_unstick (GTK_WINDOW (wbcg_toplevel (wbcg)));
 				goto finished;
 				break;
 				
 			default:  /* CANCEL */
+				gtk_window_unstick (GTK_WINDOW (wbcg_toplevel (wbcg)));
 				do_not_cancel = TRUE;
 				goto finished;
 				break;
 			}
+			gtk_window_unstick (GTK_WINDOW (wbcg_toplevel (wbcg)));
 			
 		}
 	}
@@ -202,7 +215,7 @@ client_die_cb (GnomeClient *client, gpointer data)
 {
 	GList *ptr, *workbooks;
 
-	workbooks = g_list_copy (application_workbook_list ());
+	workbooks = g_list_copy (gnm_app_workbook_list ());
 	for (ptr = workbooks; ptr != NULL ; ptr = ptr->next) {
 		Workbook *wb = ptr->data;
 
@@ -241,3 +254,9 @@ gnm_session_init (const char *argv0)
 }
 
 
+#else
+void
+gnm_session_init (const char *argv0)
+{
+}
+#endif /* WITH_GNOME */
