@@ -7,7 +7,7 @@
  *  (C) 1998-2002 Miguel de Icaza
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "style.h"
 
@@ -21,6 +21,7 @@
 
 #include "gui-util.h"
 #include "mathfunc.h"
+#include "gnumeric-gconf.h"
 
 #include <pango/pangoft2.h>
 #include <gtk/gtkmain.h>
@@ -226,7 +227,7 @@ style_font_new_simple (PangoContext *context,
 		font->ref_count++;
 
 #ifdef DEBUG_REF_COUNT
-	fprintf (stderr, __FUNCTION__ " font=%p name=%s%s%s ref_count=%d\n",
+	g_message (__FUNCTION__ " font=%p name=%s%s%s ref_count=%d\n",
 		 font, font->font_name,
 		 font->is_bold ? " bold" : "",
 		 font->is_italic ? " italic" : "",
@@ -284,7 +285,7 @@ style_font_ref (GnmFont *sf)
 
 	sf->ref_count++;
 #ifdef DEBUG_REF_COUNT
-	fprintf (stderr, __FUNCTION__ " font=%p name=%s%s%s ref_count=%d\n",
+	g_message (__FUNCTION__ " font=%p name=%s%s%s ref_count=%d\n",
 		 sf, sf->font_name,
 		 sf->is_bold ? " bold" : "",
 		 sf->is_italic ? " italic" : "",
@@ -300,7 +301,7 @@ style_font_unref (GnmFont *sf)
 
 	sf->ref_count--;
 #ifdef DEBUG_REF_COUNT
-	fprintf (stderr, __FUNCTION__ " font=%p name=%s%s%s ref_count=%d\n",
+	g_message (__FUNCTION__ " font=%p name=%s%s%s ref_count=%d\n",
 		 sf, sf->font_name,
 		 sf->is_bold ? " bold" : "",
 		 sf->is_italic ? " italic" : "",
@@ -407,22 +408,14 @@ gnm_pango_context_get (void)
 static void
 font_init (void)
 {
-	GConfClient *client = gnm_app_get_gconf_client ();
 	PangoContext *context;
 	GnmFont *gnumeric_default_font = NULL;
 	int n_families, i;
 
-	gnumeric_default_font_name =
-		gconf_client_get_string (client,
-					 GCONF_DEFAULT_FONT,
-					 NULL);
-	gnumeric_default_font_size =
-		gconf_client_get_float (client,
-					GCONF_DEFAULT_SIZE,
-					NULL);
+	gnumeric_default_font_name = g_strdup (gnm_app_prefs->default_font.name);
+	gnumeric_default_font_size = gnm_app_prefs->default_font.size;
 
 	context = gnm_pango_context_get ();
-
 	if (gnumeric_default_font_name && gnumeric_default_font_size >= 1)
 		gnumeric_default_font = style_font_new_simple (context,
 			gnumeric_default_font_name, gnumeric_default_font_size,
@@ -561,23 +554,22 @@ SpanCalcFlags
 required_updates_for_style (GnmStyle *style)
 {
 	gboolean const size_change =
-	    (mstyle_is_element_set (style, MSTYLE_FONT_NAME) ||
-	     mstyle_is_element_set (style, MSTYLE_FONT_BOLD) ||
-	     mstyle_is_element_set (style, MSTYLE_FONT_ITALIC) ||
-	     mstyle_is_element_set (style, MSTYLE_FONT_SIZE) ||
-	     mstyle_is_element_set (style, MSTYLE_WRAP_TEXT));
+	    (mstyle_is_element_set  (style, MSTYLE_FONT_NAME) ||
+	     mstyle_is_element_set  (style, MSTYLE_FONT_BOLD) ||
+	     mstyle_is_element_set  (style, MSTYLE_FONT_ITALIC) ||
+	     mstyle_is_element_set  (style, MSTYLE_FONT_SIZE) ||
+	     mstyle_is_element_set  (style, MSTYLE_WRAP_TEXT));
 	gboolean const format_change =
 	    (mstyle_is_element_set (style, MSTYLE_FORMAT) ||
-	     mstyle_is_element_set (style, MSTYLE_FONT_STRIKETHROUGH) ||
-	     mstyle_is_element_set (style, MSTYLE_FONT_UNDERLINE) ||
 	     mstyle_is_element_set (style, MSTYLE_INDENT) ||
 	     mstyle_is_element_set (style, MSTYLE_ALIGN_H) ||
-	     mstyle_is_element_set (style, MSTYLE_ALIGN_V) ||
+	     mstyle_is_element_set (style, MSTYLE_FONT_STRIKETHROUGH) ||
+	     mstyle_is_element_set (style, MSTYLE_FONT_UNDERLINE) ||
 	     mstyle_is_element_set (style, MSTYLE_COLOR_FORE));
 
 	return (format_change|size_change)
 		? (SPANCALC_RE_RENDER|SPANCALC_RESIZE)
-			  : SPANCALC_SIMPLE;
+		: SPANCALC_SIMPLE;
 }
 
 /**
