@@ -22,7 +22,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "tabulate.h"
 
@@ -47,8 +47,8 @@
 
 
 static GnmValue *
-tabulation_eval (Workbook *wb, int dims,
-		 const gnm_float *x, Cell **xcells, Cell *ycell)
+tabulation_eval (Workbook *wb, int dims, gnm_float const *x,
+		 GnmCell **xcells, GnmCell *ycell)
 {
 	int i;
 
@@ -59,14 +59,14 @@ tabulation_eval (Workbook *wb, int dims,
 	workbook_recalc (wb);
 
 	return ycell->value
-		? value_duplicate (ycell->value)
+		? value_dup (ycell->value)
 		: value_new_error_VALUE (NULL);
 }
 
-static StyleFormat const *
-my_get_format (Cell const *cell)
+static GnmFormat const *
+my_get_format (GnmCell const *cell)
 {
-	StyleFormat const *format = mstyle_get_format (cell_get_mstyle (cell));
+	GnmFormat const *format = mstyle_get_format (cell_get_mstyle (cell));
 
 	if (style_format_is_general (format) &&
 	    cell->value != NULL && VALUE_FMT (cell->value) != NULL)
@@ -76,20 +76,20 @@ my_get_format (Cell const *cell)
 
 GSList *
 do_tabulation (WorkbookControl *wbc,
-	       tabulate_t *data)
+	       GnmTabulateInfo *data)
 {
 	Workbook *wb = wb_control_workbook (wbc);
 	GSList *sheet_idx = NULL;
 	Sheet *sheet = NULL;
 	gboolean sheetdim = (!data->with_coordinates && data->dims >= 3);
-	StyleFormat const *targetformat = my_get_format (data->target);
+	GnmFormat const *targetformat = my_get_format (data->target);
 	int row = 0;
 
 	gnm_float *values = g_new (gnm_float, data->dims);
 	int *index = g_new (int, data->dims);
 	int *counts = g_new (int, data->dims);
 	Sheet **sheets = NULL;
-	StyleFormat const **formats = g_new (StyleFormat const *, data->dims);
+	GnmFormat const **formats = g_new (GnmFormat const *, data->dims);
 
 	{
 		int i;
@@ -111,7 +111,7 @@ do_tabulation (WorkbookControl *wbc,
 	if (sheetdim) {
 		int dim = 2;
 		gnm_float val = data->minima[dim];
-		StyleFormat const *sf = my_get_format (data->cells[dim]);
+		GnmFormat const *sf = my_get_format (data->cells[dim]);
 		int i;
 
 		sheets = g_new (Sheet *, counts[dim]);
@@ -148,7 +148,7 @@ do_tabulation (WorkbookControl *wbc,
 
 	while (1) {
 		GnmValue *v;
-		Cell *cell;
+		GnmCell *cell;
 		int dim;
 
 		if (data->with_coordinates) {
@@ -185,9 +185,9 @@ do_tabulation (WorkbookControl *wbc,
 
 			/* Make a horizon line on top between header and table.  */
 			if (row == 1 && col == 1) {
-				MStyle *mstyle = mstyle_new ();
+				GnmStyle *mstyle = mstyle_new ();
 				GnmRange range;
-				StyleBorder *border;
+				GnmBorder *border;
 
 				range.start.col = 0;
 				range.start.row = 0;
@@ -205,9 +205,9 @@ do_tabulation (WorkbookControl *wbc,
 
 			/* Make a vertical line on left between header and table.  */
 			if (row == 1 && col == 1) {
-				MStyle *mstyle = mstyle_new ();
+				GnmStyle *mstyle = mstyle_new ();
 				GnmRange range;
-				StyleBorder *border;
+				GnmBorder *border;
 
 				range.start.col = 0;
 				range.start.row = 0;
