@@ -5,10 +5,11 @@
  *   Miguel de Icaza (miguel@gnu.org).
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 
 #include "value.h"
+#include "format.h"
 #include "ranges.h"
 #include "str.h"
 #include "sheet.h"
@@ -16,9 +17,9 @@
 #include "workbook.h"
 #include "parse-util.h"
 
-/* Debugging utility to print a Value */
+/* Debugging utility to print a GnmValue */
 void
-value_dump (Value const *value)
+value_dump (GnmValue const *value)
 {
 	switch (value->type){
 	case VALUE_EMPTY:
@@ -30,7 +31,7 @@ value_dump (Value const *value)
 		break;
 
 	case VALUE_BOOLEAN:
-		printf ("BOOLEAN: %s\n", value->v_bool.val ?_("TRUE"):_("FALSE"));
+		printf ("BOOLEAN: %s\n", format_boolean (value->v_bool.val));
 		break;
 
 	case VALUE_STRING:
@@ -60,7 +61,7 @@ value_dump (Value const *value)
 		 * Do NOT normalize the ranges.
 		 * Lets see them in their inverted glory if need be.
 		 */
-		CellRef const *c = &value->v_range.cell.a;
+		GnmCellRef const *c = &value->v_range.cell.a;
 		Sheet const *sheet = c->sheet;
 
 		printf ("CellRange\n");
@@ -86,14 +87,13 @@ value_dump (Value const *value)
 	}
 }
 
-
 int
-value_area_get_width (EvalPos const *ep, Value const *v)
+value_area_get_width (GnmValue const *v, GnmEvalPos const *ep)
 {
 	g_return_val_if_fail (v, 0);
 
 	if (v->type == VALUE_CELLRANGE) {
-		RangeRef const *r = &v->v_range.cell;
+		GnmRangeRef const *r = &v->v_range.cell;
 		int ans = r->b.col - r->a.col;
 
 		if (r->a.col_relative) {
@@ -110,12 +110,12 @@ value_area_get_width (EvalPos const *ep, Value const *v)
 }
 
 int
-value_area_get_height (EvalPos const *ep, Value const *v)
+value_area_get_height (GnmValue const *v, GnmEvalPos const *ep)
 {
 	g_return_val_if_fail (v, 0);
 
 	if (v->type == VALUE_CELLRANGE) {
-		RangeRef const *r = &v->v_range.cell;
+		GnmRangeRef const *r = &v->v_range.cell;
 		int ans = r->b.row - r->a.row;
 
 		if (r->a.row_relative) {
@@ -132,16 +132,13 @@ value_area_get_height (EvalPos const *ep, Value const *v)
 	return 1;
 }
 
-Value const *
-value_area_fetch_x_y (EvalPos const *ep, Value const *v, int x, int y)
+GnmValue const *
+value_area_fetch_x_y (GnmValue const *v, int x, int y, GnmEvalPos const *ep)
 {
-	Value const * const res = value_area_get_x_y (ep, v, x, y);
-	static Value *value_zero = NULL;
+	GnmValue const * const res = value_area_get_x_y (v, x, y, ep);
 	if (res && res->type != VALUE_EMPTY)
 		return res;
 
-	if (value_zero == NULL)
-		value_zero = value_new_int (0);
 	return value_zero;
 }
 
@@ -149,8 +146,8 @@ value_area_fetch_x_y (EvalPos const *ep, Value const *v, int x, int y)
  * An internal routine to get a cell from an array or range.  If any
  * problems occur a NULL is returned.
  */
-Value const *
-value_area_get_x_y (EvalPos const *ep, Value const *v, int x, int y)
+GnmValue const *
+value_area_get_x_y (GnmValue const *v, int x, int y, GnmEvalPos const *ep)
 {
 	g_return_val_if_fail (v, NULL);
 
@@ -160,13 +157,13 @@ value_area_get_x_y (EvalPos const *ep, Value const *v, int x, int y)
 				      NULL);
 		return v->v_array.vals [x][y];
 	} else if (v->type == VALUE_CELLRANGE) {
-		CellRef const * const a = &v->v_range.cell.a;
-		CellRef const * const b = &v->v_range.cell.b;
+		GnmCellRef const * const a = &v->v_range.cell.a;
+		GnmCellRef const * const b = &v->v_range.cell.b;
 		int a_col = a->col;
 		int a_row = a->row;
 		int b_col = b->col;
 		int b_row = b->row;
-		Cell *cell;
+		GnmCell *cell;
 		Sheet *sheet;
 
 		/* Handle relative references */
@@ -212,9 +209,10 @@ value_area_get_x_y (EvalPos const *ep, Value const *v, int x, int y)
 			return NULL;
 
 		cell = sheet_cell_get (sheet, a_col, a_row);
-
-		if (cell && cell->value)
+		if (cell != NULL) {
+			cell_eval (cell);
 			return cell->value;
+		}
 	} else
 		return v;
 
@@ -224,42 +222,44 @@ value_area_get_x_y (EvalPos const *ep, Value const *v, int x, int y)
 typedef struct
 {
 	ValueAreaFunc  callback;
-	EvalPos const *ep;
+	GnmEvalPos const *ep;
 	void	      *real_data;
 } WrapperClosure;
 
-static Value *
+static GnmValue *
 cb_wrapper_foreach_cell_in_area (Sheet *sheet, int col, int row,
-				 Cell *cell, void *user_data)
+				 GnmCell *cell, void *user_data)
 {
-	WrapperClosure * wrap;
-	if (cell == NULL || cell->value == NULL)
-	        return NULL;
-
-       	wrap = (WrapperClosure *)user_data;
-       	return (*wrap->callback)(wrap->ep, cell->value, wrap->real_data);
+	WrapperClosure *wrap = (WrapperClosure *)user_data;
+	GnmValue const *v;
+	if (cell != NULL) {
+		cell_eval (cell);
+		v = cell->value;
+	} else
+		v = NULL;
+       	return (*wrap->callback) (v, wrap->ep, wrap->real_data);
 }
 
 /**
  * value_area_foreach:
  *
  * For each existing element in an array or range , invoke the
- * callback routine.  If the only_existing flag is passed, then
- * callbacks are only invoked for existing cells.
+ * callback routine.
  *
  * Return value:
  *    non-NULL on error, or VALUE_TERMINATE if some invoked routine requested
  *    to stop (by returning non-NULL).
  */
-Value *
-value_area_foreach (EvalPos const *ep, Value const *v,
+GnmValue *
+value_area_foreach (GnmValue const *v, GnmEvalPos const *ep,
+		    CellIterFlags flags,
 		    ValueAreaFunc callback,
 		    void *closure)
 {
 	int x, y;
-	Value *tmp;
+	GnmValue *tmp;
 
-	g_return_val_if_fail (callback != NULL, FALSE);
+	g_return_val_if_fail (callback != NULL, NULL);
 
         if (v->type == VALUE_CELLRANGE) {
 		WrapperClosure wrap;
@@ -267,34 +267,20 @@ value_area_foreach (EvalPos const *ep, Value const *v,
 		wrap.ep = ep;
 		wrap.real_data = closure;
 		return workbook_foreach_cell_in_range (
-			ep, v, CELL_ITER_IGNORE_BLANK,
+			ep, v, flags,
 			&cb_wrapper_foreach_cell_in_area,
 			(void *)&wrap);
 	}
 
 	/* If not an array, apply callback to singleton */
         if (v->type != VALUE_ARRAY)
-		return (*callback)(ep, v, closure);
+		return (*callback) (v, ep, closure);
 
 	for (x = v->v_array.x; --x >= 0;)
 		for (y = v->v_array.y; --y >= 0;)
-			if ((tmp = (*callback)(ep, v->v_array.vals [x][y], closure)) != NULL)
+			if ((tmp = (*callback)(v->v_array.vals [x][y], ep, closure)) != NULL)
 				return tmp;
 
 	return NULL;
 }
 
-/**
- * range_ref_normalize :  Take a range_ref from a Value and normalize it
- *     by converting to absolute coords and handling inversions.
- */
-void
-value_cellrange_normalize (EvalPos const *ep, Value const *ref,
-			   Sheet **start_sheet, Sheet **end_sheet, Range *dest)
-{
-	g_return_if_fail (ref != NULL);
-	g_return_if_fail (ref->type == VALUE_CELLRANGE);
-
-	rangeref_normalize   (ep, &ref->v_range.cell,
-			      start_sheet, end_sheet, dest);
-}
