@@ -9,7 +9,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "value.h"
 
@@ -1610,6 +1610,7 @@ parse_database_criteria (GnmEvalPos const *ep, GnmValue *database, GnmValue *cri
 {
 	Sheet	*sheet;
 	GnmCell	*cell;
+
         int   i;
 	int   b_col, b_row, e_col, e_row;
 	int   *field_ind;
@@ -1620,7 +1621,6 @@ parse_database_criteria (GnmEvalPos const *ep, GnmValue *database, GnmValue *cri
 	e_col = criteria->v_range.cell.b.col;
 	e_row = criteria->v_range.cell.b.row;
 
-	/* FIXME: are we sure that e_col>=b_col?  */
 	/* Find the index numbers for the columns of criterias */
 	field_ind = g_alloca (sizeof (int) * (e_col - b_col + 1));
 	for (i = b_col; i <= e_col; i++) {
@@ -1632,9 +1632,11 @@ parse_database_criteria (GnmEvalPos const *ep, GnmValue *database, GnmValue *cri
 		        continue;
 		field_ind[i - b_col] =
 		        find_column_of_field (ep, database, cell->value);
-		if (field_ind[i - b_col] == -1)
+		if (field_ind[i - b_col] == -1) {
+		        g_free (field_ind);
 			return NULL;
 		}
+	}
 
 	return parse_criteria_range (sheet, b_col, b_row + 1,
 				     e_col, e_row, field_ind);
