@@ -32,8 +32,7 @@
 
 #include <gnumeric-config.h>
 #include "gnumeric-optionmenu.h"
-#include <gnumeric-i18n.h>
-#include <gnm-marshalers.h>
+#include <glib/gi18n.h>
 
 #include "gtk/gtkmenu.h"
 #include "gtk/gtkmenuitem.h"
@@ -174,7 +173,7 @@ gnumeric_option_menu_class_init (GnumericOptionMenuClass *class)
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GnumericOptionMenuClass, changed),
                   NULL, NULL,
-                  gnm__VOID__VOID,
+                  g_cclosure_marshal_VOID__VOID,
                   G_TYPE_NONE, 0);
 
   gobject_class->set_property = gnumeric_option_menu_set_property;
@@ -419,9 +418,9 @@ gnumeric_option_menu_set_property (GObject            *object,
 
 static void
 gnumeric_option_menu_get_property (GObject            *object,
-			      guint               prop_id,
-			      GValue             *value,
-			      GParamSpec         *pspec)
+				   guint               prop_id,
+				   GValue             *value,
+				   GParamSpec         *pspec)
 {
   GnumericOptionMenu *option_menu = GNUMERIC_OPTION_MENU (object);
 
@@ -489,7 +488,7 @@ gnumeric_option_menu_get_props (GnumericOptionMenu       *option_menu,
 
 static void
 gnumeric_option_menu_size_request (GtkWidget      *widget,
-			      GtkRequisition *requisition)
+				   GtkRequisition *requisition)
 {
   GnumericOptionMenu *option_menu = GNUMERIC_OPTION_MENU (widget);
   GnumericOptionMenuProps props;
@@ -524,7 +523,7 @@ gnumeric_option_menu_size_request (GtkWidget      *widget,
 
 static void
 gnumeric_option_menu_size_allocate (GtkWidget     *widget,
-			       GtkAllocation *allocation)
+				    GtkAllocation *allocation)
 {
   GtkWidget *child;
   GtkButton *button = GTK_BUTTON (widget);
