@@ -20,14 +20,13 @@
 #include <gnumeric-config.h>
 #include "widget-format-selector.h"
 
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 
 #include <format.h>
 #include <mstyle.h>
 #include <style-color.h>
 #include <sheet.h>
 #include <value.h>
-#include <gnm-marshalers.h>
 
 #include <widgets/gnumeric-combo-text.h>
 
@@ -271,11 +270,11 @@ fillin_negative_samples (NumberFormatSelector *nfs)
 	START_LOCALE_SWITCH;
 		
 	if (nfs->format.use_separator)
-		thousand_sep = format_get_thousand ();
+		thousand_sep = format_get_thousand ()->str;
 	else
 		thousand_sep = "";
 	if (nfs->format.num_decimals > 0)
-		decimal = format_get_decimal ();
+		decimal = format_get_decimal ()->str;
 	else
 		decimal = "";
 
@@ -1081,7 +1080,7 @@ nfs_class_init (GtkObjectClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (NumberFormatSelectorClass, number_format_changed),
 			      NULL, NULL,
-			      gnm__VOID__POINTER,
+			      g_cclosure_marshal_VOID__POINTER,
 			      G_TYPE_NONE, 1, G_TYPE_POINTER);
 }
 
