@@ -20,7 +20,7 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "workbook-control-priv.h"
 
@@ -69,7 +69,8 @@ WBC_VIRTUAL (title_set,
 	(WorkbookControl *wbc, char const * title), (wbc, title))
 WBC_VIRTUAL (prefs_update,
 	(WorkbookControl *wbc), (wbc))
-WBC_VIRTUAL (format_feedback, (WorkbookControl *wbc), (wbc))
+WBC_VIRTUAL (style_feedback,
+	(WorkbookControl *wbc, GnmStyle const *changes), (wbc, changes))
 WBC_VIRTUAL (zoom_feedback,
 	(WorkbookControl *wbc), (wbc))
 WBC_VIRTUAL (edit_line_set,
@@ -78,8 +79,8 @@ WBC_VIRTUAL (selection_descr_set,
 	(WorkbookControl *wbc, char const *text), (wbc, text))
 WBC_VIRTUAL (edit_set_sensitive,
 	(WorkbookControl *wbc,
-	 gboolean ok_cancel_flag, gboolean func_guru_flag),
-	(wbc, ok_cancel_flag, func_guru_flag))
+	 gboolean enable_edit_ok_cancel, gboolean enable_actions),
+	(wbc, enable_edit_ok_cancel, enable_actions))
 WBC_VIRTUAL (auto_expr_value, (WorkbookControl *wbc), (wbc))
 
 WBC_VIRTUAL_FULL (sheet_remove, sheet.remove,
@@ -94,15 +95,13 @@ WBC_VIRTUAL_FULL (sheet_move, sheet.move,
 WBC_VIRTUAL_FULL (sheet_remove_all, sheet.remove_all,
 	(WorkbookControl *wbc), (wbc))
 
-WBC_VIRTUAL_FULL (undo_redo_clear, undo_redo.clear,
-	(WorkbookControl *wbc, gboolean is_undo), (wbc, is_undo))
 WBC_VIRTUAL_FULL (undo_redo_truncate, undo_redo.truncate,
 	(WorkbookControl *wbc, int n, gboolean is_undo), (wbc, n, is_undo))
 WBC_VIRTUAL_FULL (undo_redo_pop, undo_redo.pop,
 	(WorkbookControl *wbc, gboolean is_undo), (wbc, is_undo))
 WBC_VIRTUAL_FULL (undo_redo_push, undo_redo.push,
-	(WorkbookControl *wbc, char const *text, gboolean is_undo),
-	(wbc, text, is_undo))
+	(WorkbookControl *wbc, gboolean is_undo, char const *text, gpointer key),
+	(wbc, is_undo, text, key))
 WBC_VIRTUAL_FULL (undo_redo_labels, undo_redo.labels,
 	(WorkbookControl *wbc, char const *undo, char const *redo),
 	(wbc, undo, redo))
@@ -116,7 +115,7 @@ WBC_VIRTUAL_FULL (menu_state_sheet_count, menu_state.sheet_count,
 	(WorkbookControl *wbc), (wbc))
 
 WBC_VIRTUAL (paste_from_selection,
-	(WorkbookControl *wbc, PasteTarget const *pt), (wbc, pt))
+	(WorkbookControl *wbc, GnmPasteTarget const *pt), (wbc, pt))
 
 void
 wb_control_sheet_add (WorkbookControl *wbc, SheetView *sv)
@@ -138,7 +137,7 @@ wb_control_sheet_add (WorkbookControl *wbc, SheetView *sv)
 			wb_view_selection_desc (wbv, TRUE, wbc);
 			wb_view_edit_line_set (wbv, wbc);
 			wb_control_auto_expr_value (wbc);
-			wb_control_format_feedback (wbc);
+			wb_control_style_feedback (wbc, NULL);
 			wb_control_menu_state_sheet_prefs (wbc, new_sheet);
 			wb_control_menu_state_update (wbc, MS_ALL);
 		}
@@ -209,26 +208,30 @@ wb_control_cur_sheet_view (WorkbookControl const *wbc)
 gboolean
 wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 {
-	RangeRef const *r;
-	CellPos tmp;
+	GnmRangeRef const *r;
+	GnmCellPos tmp;
 	Sheet *sheet  = wb_control_cur_sheet (wbc);
 	SheetView *sv;
-	Value *target = global_range_parse (sheet, text);
+	GnmValue *target;
+
+	if (text == NULL || *text == '\0')
+		return FALSE;
 
 	/* not an address, is it a name ? */
+	target = global_range_parse (sheet, text);
 	if (target == NULL) {
-		ParsePos pp;
+		GnmParsePos pp;
 		GnmNamedExpr *nexpr = expr_name_lookup (
 			parse_pos_init_sheet (&pp, sheet), text);
 
 		/* If no name, or just a placeholder exists create a name */
 		if (nexpr == NULL || expr_name_is_placeholder (nexpr)) {
-			Range const *r = selection_first_range (
+			GnmRange const *r = selection_first_range (
 				wb_control_cur_sheet_view (wbc),
-				COMMAND_CONTEXT (wbc),
+				GNM_CMD_CONTEXT (wbc),
 				_("Define Name"));
 			if (r != NULL) {
-				CellRef a, b;
+				GnmCellRef a, b;
 				GnmExpr const *target_range;
 
 				a.sheet = b.sheet = sheet;
@@ -246,7 +249,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 		} else {
 			target = gnm_expr_get_range (nexpr->expr);
 			if (target == NULL) {
-				gnumeric_error_invalid (COMMAND_CONTEXT (wbc), _("Address"), text);
+				gnm_cmd_context_error_invalid (GNM_CMD_CONTEXT (wbc), _("Address"), text);
 				return FALSE;
 			}
 		}
@@ -268,7 +271,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 }
 
 static void
-cb_wbc_clipboard_modified (GnumericApplication *app, WorkbookControl *wbc)
+cb_wbc_clipboard_modified (GnmApp *app, WorkbookControl *wbc)
 {
 	wb_control_menu_state_update (wbc, MS_PASTE_SPECIAL);
 }
@@ -281,13 +284,12 @@ wbc_finalize (GObject *obj)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (obj);
 	if (wbc->clipboard_changed_signal)
-		g_signal_handler_disconnect (gnumeric_application_get_app (),
+		g_signal_handler_disconnect (gnm_app_get_app (),
 					     wbc->clipboard_changed_signal);
 	wbc->clipboard_changed_signal = 0;
 	if (wbc->wb_view != NULL)
 		wb_view_detach_control (wbc);
-	if (parent_klass != NULL && parent_klass->finalize != NULL)
-		(parent_klass)->finalize (obj);
+	(*parent_klass->finalize) (obj);
 }
 
 static void
@@ -302,18 +304,23 @@ workbook_control_init (GObject *obj)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (obj);
 
+	/* We are not in edit mode */
+	wbc->editing = FALSE;
+	wbc->editing_sheet = NULL;
+	wbc->editing_cell = NULL;
+
 	wbc->clipboard_changed_signal = g_signal_connect (
-		gnumeric_application_get_app (),
+		gnm_app_get_app (),
 		"clipboard_modified",
 		G_CALLBACK (cb_wbc_clipboard_modified), wbc);
 }
 
 GSF_CLASS (WorkbookControl, workbook_control,
 	   workbook_control_class_init, workbook_control_init,
-	   COMMAND_CONTEXT_TYPE);
+	   GNM_CMD_CONTEXT_TYPE);
 
 void
-workbook_control_set_view (WorkbookControl *wbc,
+wb_control_set_view (WorkbookControl *wbc,
 			   WorkbookView *opt_view, Workbook *opt_wb)
 {
 	WorkbookView *wbv;
@@ -326,7 +333,7 @@ workbook_control_set_view (WorkbookControl *wbc,
 }
 
 void
-workbook_control_init_state (WorkbookControl *wbc)
+wb_control_init_state (WorkbookControl *wbc)
 {
 	GList *sheets, *ptr;
 	Sheet *sheet;
