@@ -6,7 +6,6 @@
 #include "widgets/gnumeric-expr-entry.h"
 
 void	 wbcg_edit_ctor	  (WorkbookControlGUI *wbcg);
-void	 wbcg_edit_dtor	  (WorkbookControlGUI *wbcg);
 gboolean wbcg_edit_finish (WorkbookControlGUI *wbcg, gboolean accept,
 			   gboolean *showed_dialog);
 gboolean wbcg_edit_start  (WorkbookControlGUI *wbcg,
@@ -16,11 +15,13 @@ void	    wbcg_edit_attach_guru	(WorkbookControlGUI *wbcg, GtkWidget *guru);
 void	    wbcg_edit_attach_guru_with_unfocused_rs (WorkbookControlGUI *wbcg, GtkWidget *guru,
 						     GnmExprEntry *gee);
 void	    wbcg_edit_detach_guru	(WorkbookControlGUI *wbcg);
-GtkWidget  *wbcg_edit_has_guru		(WorkbookControlGUI const *wbcg);
+GtkWidget  *wbcg_edit_get_guru		(WorkbookControlGUI const *wbcg);
 gboolean    wbcg_edit_entry_redirect_p	(WorkbookControlGUI const *wbcg);
 gboolean    wbcg_auto_completing        (WorkbookControlGUI const *wbcg);
 void	    wbcg_auto_complete_destroy  (WorkbookControlGUI *wbcg);
 char const *wbcg_edit_get_display_text	(WorkbookControlGUI *wbcg);
+void	    wbcg_edit_add_markup	(WorkbookControlGUI *wbcg, PangoAttribute *attr);
+PangoAttrList *wbcg_edit_get_markup	(WorkbookControlGUI *wbcg, gboolean full);
 
 GtkEntry     *wbcg_get_entry  	     (WorkbookControlGUI const  *wbcg);
 GnmExprEntry *wbcg_get_entry_logical (WorkbookControlGUI const  *wbcg);
