@@ -60,9 +60,8 @@ GnmStyle      *xml_read_style     (XmlParseContext *ctxt, xmlNodePtr tree);
 
 void      xml_init (void);
 
-xmlNode *e_xml_get_child_by_name		(xmlNode const *tree, char const *name);
-xmlNode *e_xml_get_child_by_name_no_lang	(xmlNode const *tree, char const *name);
-xmlNode *e_xml_get_child_by_name_by_lang_list	(xmlNode const *tree, char const *name,
-						 GList const *lang_list);
+xmlNode *e_xml_get_child_by_name	 (xmlNode const *tree, char const *name);
+xmlNode *e_xml_get_child_by_name_no_lang (xmlNode const *tree, char const *name);
+xmlNode *e_xml_get_child_by_name_by_lang (xmlNode const *tree, char const *name);
 
 #endif /* GNUMERIC_XML_IO_H */
